@@ -1,6 +1,6 @@
-// $Id: CommandLine.cpp,v 1.66 2005/10/24 15:38:13 geuzaine Exp $
+// $Id: CommandLine.cpp,v 1.101 2007-05-24 17:34:03 geuzaine Exp $
 //
-// Copyright (C) 1997-2005 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -19,20 +19,21 @@
 // 
 // Please report all bugs and problems to <gmsh@geuz.org>.
 
-#include <sys/types.h>
-#include <unistd.h>
 #include "Gmsh.h"
 #include "GmshUI.h"
+#include "GmshDefines.h"
 #include "GmshVersion.h"
 #include "CommandLine.h"
 #include "Numeric.h"
 #include "Context.h"
 #include "Options.h"
 #include "Geo.h"
-#include "Mesh.h"
 #include "Views.h"
 #include "OpenFile.h"
+#include "CreateFile.h"
 #include "Parser.h"
+#include "GModel.h"
+#include "OS.h"
 
 #if !defined(GMSH_EXTRA_VERSION)
 #error
@@ -42,10 +43,10 @@
 #endif
 
 extern Context_T CTX;
-extern Mesh *THEM;
+extern GModel *GMODEL;
 
 char gmsh_progname[]  = "Gmsh, a 3D mesh generator with pre- and post-processing facilities" ;
-char gmsh_copyright[] = "Copyright (C) 1997-2005 Christophe Geuzaine and Jean-Francois Remacle";
+char gmsh_copyright[] = "Copyright (C) 1997-2007 Christophe Geuzaine and Jean-Francois Remacle";
 char gmsh_version[]   = "Version        : " ;
 char gmsh_license[]   = "License        : " GMSH_SHORT_LICENSE;
 char gmsh_gui[]       = "GUI toolkit    : " ;
@@ -57,35 +58,43 @@ char gmsh_packager[]  = "Packager       : " GMSH_PACKAGER ;
 char gmsh_url[]       = "Web site       : http://www.geuz.org/gmsh/" ;
 char gmsh_email[]     = "Mailing list   : gmsh@geuz.org" ;
 
-// If you change the following, please also change
-// * the texinfo documentation (doc/texinfo/command_line.texi)
-// * the man page (doc/gmsh.1)
+int Get_GmshMajorVersion(){ return GMSH_MAJOR_VERSION; }
+int Get_GmshMinorVersion(){ return GMSH_MINOR_VERSION; }
+int Get_GmshPatchVersion(){ return GMSH_PATCH_VERSION; }
+char *Get_GmshExtraVersion(){ return GMSH_EXTRA_VERSION; }
+char *Get_GmshVersion(){ return GMSH_VERSION; }
+char *Get_GmshBuildDate(){ return GMSH_DATE; }
+char *Get_GmshBuildHost(){ return GMSH_HOST; }
+char *Get_GmshPackager(){ return GMSH_PACKAGER; }
+char *Get_GmshBuildOS(){ return GMSH_OS; }
+char *Get_GmshShortLicense(){ return GMSH_SHORT_LICENSE; }
 
 void Print_Usage(char *name){
+  // If you make changes in this routine, please also change the
+  // texinfo documentation (doc/texinfo/command_line.texi) as well as
+  // the man page (doc/gmsh.1)
   Msg(DIRECT, "Usage: %s [options] [files]", name);
   Msg(DIRECT, "Geometry options:");
-  Msg(DIRECT, "  -0                    Parse input files, output unrolled geometry, and exit");
+  Msg(DIRECT, "  -0                    Output unrolled geometry, then exit");
+  Msg(DIRECT, "  -tol float            Set geometrical tolerance");
   Msg(DIRECT, "Mesh options:");
-  Msg(DIRECT, "  -1, -2, -3            Perform batch 1D, 2D and 3D mesh generation");
+  Msg(DIRECT, "  -1, -2, -3            Perform 1D, 2D or 3D mesh generation, then exit");
   Msg(DIRECT, "  -saveall              Save all elements (discard physical group definitions)");
   Msg(DIRECT, "  -o file               Specify mesh output file name");
-  Msg(DIRECT, "  -format string        Set output mesh format (msh, unv, gref, stl, p3d)");
-  Msg(DIRECT, "  -algo string          Select mesh algorithm (iso, tri, aniso, netgen, tetgen)");
+  Msg(DIRECT, "  -format string        Set output mesh format (msh, msh1, msh2, unv, vrml, stl, mesh,");
+  Msg(DIRECT, "                          bdf, p3d, cgns, med)");
+  Msg(DIRECT, "  -bin                  Use binary format when available");  
+  Msg(DIRECT, "  -algo string          Select mesh algorithm (iso, netgen, tetgen)");
   Msg(DIRECT, "  -smooth int           Set number of mesh smoothing steps");
   Msg(DIRECT, "  -optimize             Optimize quality of tetrahedral elements");
-  Msg(DIRECT, "  -partition int        Load a mesh and partition it into $1 parts (METIS is required)");
-  Msg(DIRECT, "  -order int            Set mesh order (1, 2)");
-  Msg(DIRECT, "  -scale float          Set global scaling factor");
-  Msg(DIRECT, "  -meshscale float      Set mesh scaling factor");
+  Msg(DIRECT, "  -order int            Set mesh order (1, ..., 5)");
+  Msg(DIRECT, "  -optimize_hom         Optimize higher order meshes (in 2D)");
   Msg(DIRECT, "  -clscale float        Set characteristic length scaling factor");
+  Msg(DIRECT, "  -clcurv               Compute characteristic lengths from curvatures");
   Msg(DIRECT, "  -rand float           Set random perturbation factor");
   Msg(DIRECT, "  -bgm file             Load background mesh from file");
   Msg(DIRECT, "  -constrain            Constrain background mesh with characteristic lengths");
-  Msg(DIRECT, "  -histogram            Print mesh quality histogram");
-  Msg(DIRECT, "  -extrude              Use old extrusion mesh generator");
-  Msg(DIRECT, "  -recombine            Recombine meshes from old extrusion mesh generator");
 #if defined(HAVE_FLTK)
-  Msg(DIRECT, "  -interactive          Display 2D mesh construction interactively");
   Msg(DIRECT, "Post-processing options:");
   Msg(DIRECT, "  -noview               Hide all views on startup");
   Msg(DIRECT, "  -link int             Select link mode between views (0, 1, 2, 3, 4)");
@@ -93,20 +102,21 @@ void Print_Usage(char *name){
   Msg(DIRECT, "Display options:");    
   Msg(DIRECT, "  -nodb                 Disable double buffering");
   Msg(DIRECT, "  -fontsize int         Specify the font size for the GUI");
-  Msg(DIRECT, "  -scheme string        Specify FLTK GUI scheme");
+  Msg(DIRECT, "  -theme string         Specify FLTK GUI theme");
   Msg(DIRECT, "  -display string       Specify display");
 #endif
   Msg(DIRECT, "Other options:");      
+  Msg(DIRECT, "  -                     Parse input files, then exit");
 #if defined(HAVE_FLTK)
   Msg(DIRECT, "  -a, -g, -m, -s, -p    Start in automatic, geometry, mesh, solver or post-processing mode");
 #endif
   Msg(DIRECT, "  -pid                  Print process id on stdout");
-  Msg(DIRECT, "  -listen               Always listen to external solver requests");
+  Msg(DIRECT, "  -listen               Always listen to incoming connection requests");
   Msg(DIRECT, "  -v int                Set verbosity level");
   Msg(DIRECT, "  -nopopup              Don't popup dialog windows in scripts");
   Msg(DIRECT, "  -string \"string\"      Parse option string at startup");
   Msg(DIRECT, "  -option file          Parse option file at startup");
-  Msg(DIRECT, "  -convert file file    Perform batch conversion of views and meshes into latest file formats");
+  Msg(DIRECT, "  -convert files        Convert files into latest binary formats, then exit");
   Msg(DIRECT, "  -version              Show version number");
   Msg(DIRECT, "  -info                 Show detailed version information");
   Msg(DIRECT, "  -help                 Show this message");
@@ -147,6 +157,15 @@ char *Get_BuildOptions(void)
 #endif
 #if defined(HAVE_ANN_)
     strcat(opt, "ANN ");
+#endif
+#if defined(HAVE_CGNS)
+    strcat(opt, "CGNS ");
+#endif
+#if defined(HAVE_OCC)
+    strcat(opt, "OCC ");
+#endif
+#if defined(HAVE_MED)
+    strcat(opt, "MED ");
 #endif
     first = 0;
   }
@@ -156,8 +175,8 @@ char *Get_BuildOptions(void)
 void Get_Options(int argc, char *argv[])
 {
   // Parse session and option files
-  ParseFile(CTX.session_filename_fullpath, 1, 1);
-  ParseFile(CTX.options_filename_fullpath, 1, 1);
+  ParseFile(CTX.session_filename_fullpath, 1);
+  ParseFile(CTX.options_filename_fullpath, 1);
 
   // Get command line options
   int i = 1;
@@ -165,8 +184,28 @@ void Get_Options(int argc, char *argv[])
 
     if(argv[i][0] == '-') {
 
-      if(!strcmp(argv[i] + 1, "pid")) {
-	fprintf(stdout, "%d\n", getpid());
+      if(!strcmp(argv[i] + 1, "")) {
+        CTX.batch = -2;
+        i++;
+      }
+      else if(!strcmp(argv[i] + 1, "0")) {
+        CTX.batch = -1;
+        i++;
+      }
+      else if(!strcmp(argv[i] + 1, "1")) {
+        CTX.batch = 1;
+        i++;
+      }
+      else if(!strcmp(argv[i] + 1, "2")) {
+        CTX.batch = 2;
+        i++;
+      }
+      else if(!strcmp(argv[i] + 1, "3")) {
+        CTX.batch = 3;
+        i++;
+      }
+      else if(!strcmp(argv[i] + 1, "pid")) {
+	fprintf(stdout, "%d\n", GetProcessId());
 	fflush(stdout);
         i++;
       }
@@ -190,42 +229,10 @@ void Get_Options(int argc, char *argv[])
         CTX.initial_context = 4;
         i++;
       }
-      else if(!strcmp(argv[i] + 1, "0")) {
-        CTX.batch = -1;
-        i++;
-      }
-      else if(!strcmp(argv[i] + 1, "1")) {
-        CTX.batch = 1;
-        i++;
-      }
-      else if(!strcmp(argv[i] + 1, "2")) {
-        CTX.batch = 2;
-        i++;
-      }
-      else if(!strcmp(argv[i] + 1, "3")) {
-        CTX.batch = 3;
-        i++;
-      }
       else if(!strcmp(argv[i] + 1, "saveall")) {
         CTX.mesh.save_all = 1;
         i++;
       }
-      else if(!strcmp(argv[i] + 1, "extrude")) { // old extrusion mesh generator
-        CTX.mesh.oldxtrude = 1;
-        i++;
-      }
-      else if(!strcmp(argv[i] + 1, "recombine")) { // old extrusion mesh generator
-        CTX.mesh.oldxtrude_recombine = 1;
-        i++;
-      }
-      else if(!strcmp(argv[i] + 1, "dupli")) {
-        CTX.mesh.check_duplicates = 1;
-        i++;
-      }
-      else if(!strcmp(argv[i] + 1, "histogram")) {
-        CTX.mesh.histogram = 1;
-        i++;
-      }
       else if(!strcmp(argv[i] + 1, "optimize")) {
         CTX.mesh.optimize = 1;
         i++;
@@ -246,7 +253,7 @@ void Get_Options(int argc, char *argv[])
       else if(!strcmp(argv[i] + 1, "option")) {
         i++;
         if(argv[i] != NULL)
-          ParseFile(argv[i++], 1, 1);
+          ParseFile(argv[i++], 1);
         else {
           fprintf(stderr, ERROR_STR "Missing file name\n");
           exit(1);
@@ -278,37 +285,30 @@ void Get_Options(int argc, char *argv[])
         i++;
         CTX.terminal = 1;
         CTX.batch = 1;
-        if(argv[i] && argv[i + 1]) {
-          OpenProblem(argv[i]);
-	  // convert post-processing views to latest (binary) format
-          for(int j = 0; j < List_Nbr(CTX.post.list); j++)
-            WriteView(*(Post_View **) List_Pointer(CTX.post.list, j),
-                      argv[i + 1], 1, j ? 1 : 0);
-	  // convert any mesh to the latest format
-	  if(THEM){
-	    if(Tree_Nbr(THEM->Vertices)){
-	      CTX.mesh.msh_file_version = 2.0;
-	      Print_Mesh(THEM, argv[i + 1], FORMAT_MSH);
-	    }
+	while(i < argc) {
+	  char filename[256];
+	  sprintf(filename, "%s_new", argv[i]);
+	  int numviews_old = List_Nbr(CTX.post.list);
+          OpenProject(argv[i]);
+	  // convert post-processing views to latest binary format
+          for(int j = numviews_old; j < List_Nbr(CTX.post.list); j++){
+	    Post_View *v = *(Post_View **)List_Pointer(CTX.post.list, j);
+            WriteView(v, filename, 1, (j == numviews_old) ? 0 : 1);
 	  }
+	  // convert mesh to latest binary format
+	  if(GMODEL->getMeshStatus() > 0){
+	    CTX.mesh.msh_file_version = 2.0;
+	    CTX.mesh.msh_binary = 1;
+	    CreateOutputFile(filename, FORMAT_MSH);
+	  }
+	  i++;
         }
-        else
-          fprintf(stderr, "Usage: %s -convert file file\n", argv[0]);
         exit(1);
       }
-      else if(!strcmp(argv[i] + 1, "initial")) {
+      else if(!strcmp(argv[i] + 1, "tol")) {
         i++;
         if(argv[i] != NULL)
-          CTX.mesh.initial_only = atoi(argv[i++]);
-        else {
-          fprintf(stderr, ERROR_STR "Missing number\n");
-          exit(1);
-        }
-      }
-      else if(!strcmp(argv[i] + 1, "quality")) {
-        i++;
-        if(argv[i] != NULL)
-          CTX.mesh.quality = atof(argv[i++]);
+          CTX.geom.tolerance = atof(argv[i++]);
         else {
           fprintf(stderr, ERROR_STR "Missing number\n");
           exit(1);
@@ -356,15 +356,9 @@ void Get_Options(int argc, char *argv[])
           exit(1);
         }
       }
-      else if(!strcmp(argv[i] + 1, "partition")) {
+      else if(!strcmp(argv[i] + 1, "clcurv")) {
+        CTX.mesh.lc_from_curvature = 1;
         i++;
-        if(argv[i] != NULL) {
-          CTX.mesh.nbPartitions = atoi(argv[i++]);
-        }
-        else {
-          fprintf(stderr, ERROR_STR "Missing number\n");
-          exit(1);
-        }
       }
       else if(!strcmp(argv[i] + 1, "smooth")) {
         i++;
@@ -384,28 +378,43 @@ void Get_Options(int argc, char *argv[])
           exit(1);
         }
       }
+      else if(!strcmp(argv[i] + 1, "c1")) {
+        i++;
+	opt_mesh_c1(0, GMSH_SET, 1);
+      }
+      else if(!strcmp(argv[i] + 1, "optimize_hom")) {
+        i++;
+	opt_mesh_smooth_internal_edges(0, GMSH_SET, 1);
+      }
       else if(!strcmp(argv[i] + 1, "format") || !strcmp(argv[i] + 1, "f")) {
         i++;
         if(argv[i] != NULL) {
-          if(!strcmp(argv[i], "msh") ||
-             !strcmp(argv[i], "MSH") || !strcmp(argv[i], "gmsh")) {
+          if(!strcmp(argv[i], "msh1")){
             CTX.mesh.format = FORMAT_MSH;
-          }
-          else if(!strcmp(argv[i], "unv") ||
-                  !strcmp(argv[i], "UNV") || !strcmp(argv[i], "ideas")) {
+	    CTX.mesh.msh_file_version = 1.0;
+	  }
+          else if(!strcmp(argv[i], "msh2")){
+            CTX.mesh.format = FORMAT_MSH;
+	    CTX.mesh.msh_file_version = 2.0;
+	  }
+          else if(!strcmp(argv[i], "msh"))
+            CTX.mesh.format = FORMAT_MSH;
+          else if(!strcmp(argv[i], "unv"))
             CTX.mesh.format = FORMAT_UNV;
-          }
-          else if(!strcmp(argv[i], "gref") ||
-                  !strcmp(argv[i], "GREF") || !strcmp(argv[i], "Gref")) {
-            CTX.mesh.format = FORMAT_GREF;
-          }
-          else if(!strcmp(argv[i], "stl") || !strcmp(argv[i], "STL")) {
+          else if(!strcmp(argv[i], "vrml"))
+            CTX.mesh.format = FORMAT_VRML;
+	  else if(!strcmp(argv[i], "stl"))
             CTX.mesh.format = FORMAT_STL;
-          }
-          else if(!strcmp(argv[i], "p3d") ||
-                  !strcmp(argv[i], "P3D") || !strcmp(argv[i], "Plot3D")) {
+          else if(!strcmp(argv[i], "mesh"))
+            CTX.mesh.format = FORMAT_MESH;
+          else if(!strcmp(argv[i], "bdf"))
+            CTX.mesh.format = FORMAT_BDF;
+          else if(!strcmp(argv[i], "p3d"))
             CTX.mesh.format = FORMAT_P3D;
-          }
+          else if(!strcmp(argv[i], "cgns"))
+            CTX.mesh.format = FORMAT_CGNS;
+          else if(!strcmp(argv[i], "med"))
+            CTX.mesh.format = FORMAT_MED;
           else {
             fprintf(stderr, ERROR_STR "Unknown mesh format\n");
             exit(1);
@@ -417,19 +426,23 @@ void Get_Options(int argc, char *argv[])
           exit(1);
         }
       }
+      else if(!strcmp(argv[i] + 1, "bin")) {
+        i++;
+	CTX.mesh.stl_binary = CTX.mesh.msh_binary = 1;
+      }
       else if(!strcmp(argv[i] + 1, "algo")) {
         i++;
         if(argv[i] != NULL) {
-          if(!strncmp(argv[i], "iso", 3))
-            CTX.mesh.algo2d = DELAUNAY_ISO;
-          else if(!strncmp(argv[i], "tri", 3))
-            CTX.mesh.algo2d = DELAUNAY_TRIANGLE;
-          else if(!strncmp(argv[i], "aniso", 5))
-            CTX.mesh.algo2d = DELAUNAY_ANISO;
+          if(!strncmp(argv[i], "del3d", 5) || !strncmp(argv[i], "tetgen", 6))
+            CTX.mesh.algo2d = ALGO_3D_TETGEN_DELAUNAY;
           else if(!strncmp(argv[i], "netgen", 6))
-            CTX.mesh.algo3d = FRONTAL_NETGEN;
-          else if(!strncmp(argv[i], "tetgen", 6))
-            CTX.mesh.algo3d = DELAUNAY_TETGEN;
+            CTX.mesh.algo3d = ALGO_3D_NETGEN;
+          else if(!strncmp(argv[i], "del2d", 5) || !strncmp(argv[i], "tri", 3))
+            CTX.mesh.algo2d = ALGO_2D_DELAUNAY;
+          else if(!strncmp(argv[i], "bds", 3))
+            CTX.mesh.algo2d = ALGO_2D_MESHADAPT;
+          else if(!strncmp(argv[i], "del", 3) || !strncmp(argv[i], "iso", 3))
+	    CTX.mesh.algo2d = ALGO_2D_MESHADAPT_DELAUNAY;
           else {
             fprintf(stderr, ERROR_STR "Unknown mesh algorithm\n");
             exit(1);
@@ -492,10 +505,6 @@ void Get_Options(int argc, char *argv[])
         CTX.mesh.dual = 1;
         i++;
       }
-      else if(!strcmp(argv[i] + 1, "interactive")) {
-        CTX.mesh.interactive = 1;
-        i++;
-      }
       else if(!strcmp(argv[i] + 1, "noview")) {
         opt_view_visible(0, GMSH_SET, 0);
         i++;
@@ -532,10 +541,10 @@ void Get_Options(int argc, char *argv[])
           exit(1);
         }
       }
-      else if(!strcmp(argv[i] + 1, "scheme")) {
+      else if(!strcmp(argv[i] + 1, "theme") || !strcmp(argv[i] + 1, "scheme")) {
         i++;
         if(argv[i] != NULL) {
-          CTX.scheme = argv[i];
+          CTX.gui_theme = argv[i];
           i++;
         }
         else {
