@@ -1,7 +1,7 @@
 #ifndef _CONTEXT_H_
 #define _CONTEXT_H_
 
-// Copyright (C) 1997-2005 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -22,23 +22,6 @@
 
 #include "List.h"
 
-// How RGBA values are packed and unpacked into/from a 4-byte
-// integer:
-
-#if defined(__BIG_ENDIAN__)
-#  define PACK_COLOR(R,G,B,A)   ( (unsigned int)((R)<<24 | (G)<<16 | (B)<<8 | (A)) )
-#  define UNPACK_RED(X)         ( ( (X) >> 24 ) & 0xff )
-#  define UNPACK_GREEN(X)       ( ( (X) >> 16 ) & 0xff )
-#  define UNPACK_BLUE(X)        ( ( (X) >> 8 ) & 0xff )
-#  define UNPACK_ALPHA(X)       ( (X) & 0xff )
-#else
-#  define PACK_COLOR(R,G,B,A)   ( (unsigned int)((A)<<24 | (B)<<16 | (G)<<8 | (R)) )
-#  define UNPACK_RED(X)         ( (X) & 0xff )
-#  define UNPACK_GREEN(X)       ( ( (X) >> 8 ) & 0xff )
-#  define UNPACK_BLUE(X)        ( ( (X) >> 16 ) & 0xff )
-#  define UNPACK_ALPHA(X)       ( ( (X) >> 24 ) & 0xff )
-#endif
-
 // Interface-independent context 
 
 class Context_T {
@@ -69,7 +52,7 @@ public :
   char *editor;               // text editor command (with included '%s')
   char *web_browser;          // web browser command (with included '%s')
   char home_dir[256];         // the home directory
-  char *scheme;               // FLTK GUI theme
+  char *gui_theme;            // FLTK GUI theme
   int  tooltips;              // show tootips in GUI?
 
   int position[2];            // position of the menu window on the screen
@@ -83,6 +66,8 @@ public :
   int stat_position[2];       // position of the statistics window on the screen
   int ctx_position[2];        // position of the geo/mesh context windows on the screen
   int solver_position[2];     // position of the solver windows on the screen
+  int plugin_position[2];     // position of the plugin window on the screen
+  int plugin_size[2];         // size of the plugin window on the screen
   int file_chooser_position[2]; // position of the file chooser window on the screen
   int system_menu_bar;        // use the system menu bar on MacOS?
 
@@ -94,6 +79,7 @@ public :
   double rot[16];             // current rotation matrix 
   double r[3];                // current Euler angles (in degrees!) 
   double t[3], s[3];          // current translation and scale 
+  double t_init[3];           // initial translation before applying modelview transform
   double clip_factor;         // clipping plane distance factor
   double quaternion[4];       // current quaternion used for "trackball" rotation
   int useTrackball;           // do or do not use the trackball for rotations 
@@ -102,14 +88,13 @@ public :
   double min[3];              // x, y and z min for the current geometry 
   double max[3];              // x, y and z max for the current geometry 
   double cg[3];               // "center of mass" of the current geometry
-  double range[3];            // maximum range in the three directions 
   double lc;                  // characteristic length for the whole problem (never
                               // used in mesh generation ->only for geo/post) 
 
-  int db;                     // double buffer? 
+  int db, antialiasing;       // double buffer? antialiasing?
   int ortho;                  // orthogonal projection? 
-  int draw_bbox;              // always draw the bounding boxes?
-  int fast_redraw;            // only draw the bbox when rotating/panning the model?
+  int draw_bbox, draw_rotation_center; // draw the bounding boxes and the rot center?
+  int fast_redraw;            // draw simplified model during user interaction
   int small_axes, small_axes_size, small_axes_pos[2]; // small axes
   int axes, axes_auto_position, axes_tics[3]; // large axes
   double axes_position[6];  
@@ -117,6 +102,7 @@ public :
   int threads, threads_lock;  // threads?, lock (should be a mutex...) 
   int alpha;                  // enable alpha blending 
   double zoom_factor;         // mouse2 zoom coefficient
+  int bg_gradient;            // draw background gradient?
 
   int fontsize;               // font size for fltk UI
   char *gl_font;              // font for opengl graphics
@@ -138,7 +124,6 @@ public :
                               // approximative equivalent model length of a pixel 
   int color_scheme ;          // general color scheme
   int quadric_subdivisions;   // nb of subdivisions for gluQuadrics (spheres/cylinders)
-  int visibility_mode ;       // VIS_GEOM, VIS_MESH, ...
   int vector_type;            // default vector display type (for normals, etc.)
   double arrow_rel_head_radius;  // relative radius of arrow head
   double arrow_rel_stem_radius;  // relative radius of arrow stem
@@ -146,61 +131,65 @@ public :
 
   double model[16], proj[16]; // the modelview and projection matrix as they were
                               // at the time of the last InitPosition() call
+  double mesh_timer[3]; // records cpu times for 1-D, 2-D and 3-D mesh generation
 
   int forced_bbox; // dynamic variable tracking if the bbox is currently imposed
 
+  int enable_mouse_selection; // enable selection using the mouse
+  int pick_elements; // allow individual element picking
+
+  int expert_mode; // to disable some warnings for beginners
+  int printing; // dynamic: equal to 1 while gmsh is printing
+
   // geometry options 
   struct{
-    int vis_type;
     int points, lines, surfaces, volumes;
     int points_num, lines_num, surfaces_num, volumes_num;
     double point_size, line_width, point_sel_size, line_sel_width;
     int point_type, line_type; // flat or 3D
-    int light;
-    int level, old_circle, circle_points, circle_warning;
-    int extrude_spline_points, old_newreg;
+    int draw, light;
+    int old_circle, circle_points;
+    int extrude_spline_points, extrude_return_lateral, old_newreg;
     double normals, tangents;
     double scaling_factor;
-    int auto_coherence;
+    int auto_coherence, highlight_orphans;
+    double tolerance;
+    double snap[3];
+    int occ_fix_small_edges, occ_fix_small_faces, occ_sew_faces;
   } geom;
 
   // mesh options 
   struct {
     double msh_file_version;
-    int vis_type, changed, vertex_arrays;
-    int draw;
-    int points, lines, surfaces_edges, surfaces_faces, volumes_edges, volumes_faces;
+    int changed, draw;
+    int points, lines, triangles, quadrangles, tetrahedra, hexahedra, prisms, pyramids;
+    int surfaces_edges, surfaces_faces, volumes_edges, volumes_faces;
     int points_num, lines_num, surfaces_num, volumes_num;
     double label_frequency;
-    int point_type, line_type; // flat or 3D
+    int point_type; // flat or 3D
     double point_size, line_width;
-    int points_per_element;
     int optimize;
-    double quality;
     int quality_type, label_type;
     double quality_inf, quality_sup, radius_inf, radius_sup;
     double scaling_factor, lc_factor, rand_factor;
-    int dual, interactive;
+    int dual;
     int light, light_two_side, light_lines;
-    int format, nbPartitions,nb_smoothing, algo2d, algo3d, order,algo_recombine;
-    int point_insertion, speed_max, min_circ_points, constrained_bgmesh;
-    int histogram, initial_only;
+    int format, nb_smoothing, algo2d, algo3d, algo_recombine;
+    int order, second_order_linear, second_order_incomplete, smooth_internal_edges, c1_continuity;
+    int min_circ_points;
+    int constrained_bgmesh, lc_from_curvature;
     double normals, tangents, explode;
-    int color_carousel ;
-    int use_cut_plane, cut_plane_as_surface, cut_plane_only_volume;
-    double cut_planea,cut_planeb,cut_planec,cut_planed;
+    int color_carousel;
+    int use_cut_plane, cut_plane_draw_intersect, cut_plane_only_volume;
+    double cut_planea, cut_planeb, cut_planec, cut_planed;
     double evalCutPlane (double x, double y, double z){
       double val = cut_planea * x + cut_planeb * y + cut_planec * z + cut_planed; 
       return val;
     }
-    int oldxtrude, oldxtrude_recombine, check_duplicates;
-    int allow_degenerated_extrude, save_all;
+    int save_all, save_groups_of_nodes, stl_binary, msh_binary, bdf_field_format;
     char *triangle_options;
-    int smooth_normals;
+    int smooth_normals, reverse_all_normals;
     double angle_smooth_normals;
-    double stl_distance_tol, dihedral_angle_tol;
-    int edge_prolongation_threshold, do_not_coarsen;
-    double  nb_elem_per_rc ,   min_elem_size_fact , target_elem_size_fact, beta_smooth_metric;
   } mesh;
 
   // post processing options 
@@ -228,21 +217,21 @@ public :
     double eps_line_width_factor, eps_point_size_factor;
     int jpeg_quality, jpeg_smoothing;
     int gif_dither, gif_sort, gif_interlace, gif_transparent;
-    int gl_fonts;
+    int geo_labels;
+    int text, tex_as_equation;
   } print;
 
   // color options
   struct{
-    unsigned int bg, fg, text, axes, small_axes;
+    unsigned int bg, bg_grad, fg, text, axes, small_axes;
     unsigned int ambient_light[6], diffuse_light[6], specular_light[6];
     struct{
       unsigned int point, line, surface, volume;
-      unsigned int point_sel, line_sel, surface_sel, volume_sel;
-      unsigned int point_hlt, line_hlt, surface_hlt, volume_hlt;
+      unsigned int selection, highlight[3];
       unsigned int tangents, normals;
     } geom;
     struct{
-      unsigned int vertex, vertex_deg2, line, triangle, quadrangle;
+      unsigned int vertex, vertex_sup, line, triangle, quadrangle;
       unsigned int tetrahedron, hexahedron, prism, pyramid;
       unsigned int carousel[20];
       unsigned int tangents, normals;
@@ -253,8 +242,35 @@ public :
   void buildRotationMatrix(void);
   void setQuaternion(double p1x, double p1y, double p2x, double p2y);
   void addQuaternion(double p1x, double p1y, double p2x, double p2y);
+  void addQuaternionFromAxisAndAngle(double axis[3], double angle);
   void setQuaternionFromEulerAngles(void);
   void setEulerAnglesFromRotationMatrix(void);
+
+  int big_endian; // is the machine big-endian?
+
+  // how RGBA values are packed and unpacked into/from an unsigned
+  // integer to be fed to glColor4ubv (depends on machine byte
+  // ordering!):
+  inline unsigned int PACK_COLOR(int R, int G, int B, int A){
+    if(big_endian) return ( (unsigned int)((R)<<24 | (G)<<16 | (B)<<8 | (A)) );
+    else           return ( (unsigned int)((A)<<24 | (B)<<16 | (G)<<8 | (R)) );
+  }
+  inline int UNPACK_RED(unsigned int X){
+    if(big_endian) return ( ( (X) >> 24 ) & 0xff );
+    else           return ( (X) & 0xff );
+  }
+  inline int UNPACK_GREEN(unsigned int X){
+    if(big_endian) return ( ( (X) >> 16 ) & 0xff );
+    else           return ( ( (X) >> 8 ) & 0xff );
+  }
+  inline int UNPACK_BLUE(unsigned int X){
+    if(big_endian) return ( ( (X) >> 8 ) & 0xff );
+    else           return ( ( (X) >> 16 ) & 0xff );
+  }
+  inline int UNPACK_ALPHA(unsigned int X){
+    if(big_endian) return ( (X) & 0xff );
+    else           return ( ( (X) >> 24 ) & 0xff );
+  }
 };
 
 #endif
