@@ -1,7 +1,7 @@
 #ifndef _GMSH_UI_H_
 #define _GMSH_UI_H_
 
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -38,11 +38,13 @@
 #  else
 #    include <GL/glu.h>
 #  endif
-# define GMSH_WINDOW_BOX   FL_FLAT_BOX
-# define GMSH_TOGGLE_BOX   FL_DOWN_BOX
-# define GMSH_TOGGLE_COLOR FL_BLACK
-# define GMSH_RADIO_BOX    FL_ROUND_DOWN_BOX
-# define GMSH_RADIO_COLOR  FL_BLACK
+# define GMSH_WINDOW_BOX FL_FLAT_BOX
+#endif
+
+// recent Cygwin releases define min/max macros! 
+#if defined(__CYGWIN__)
+#undef min
+#undef max
 #endif
 
 #endif
