@@ -1,6 +1,6 @@
-// $Id: License.cpp,v 1.6 2006/01/06 00:34:21 geuzaine Exp $
+// $Id: License.cpp,v 1.9 2007-01-28 17:26:53 geuzaine Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -23,11 +23,32 @@
 
 void print_license(void)
 {
+  Msg(DIRECT, "Gmsh is provided under the terms of the GNU General Public License");
+  Msg(DIRECT, "(GPL) with the following exception:");
+  Msg(DIRECT, " ");
+  Msg(DIRECT, "  The copyright holders of Gmsh give you permission to combine Gmsh");
+  Msg(DIRECT, "  with code included in the standard release of Triangle (written by");
+  Msg(DIRECT, "  Jonathan Shewchuk), TetGen (written by Hang Si) and Netgen (written");
+  Msg(DIRECT, "  by Joachim Schoberl) under their respective licenses. You may copy");
+  Msg(DIRECT, "  and distribute such a system following the terms of the GNU GPL for");
+  Msg(DIRECT, "  Gmsh and the licenses of the other code concerned, provided that you");
+  Msg(DIRECT, "  include the source code of that other code when and as the GNU GPL");
+  Msg(DIRECT, "  requires distribution of source code.");
+  Msg(DIRECT, " ");
+  Msg(DIRECT, "  Note that people who make modified versions of Gmsh are not");
+  Msg(DIRECT, "  obligated to grant this special exception for their modified");
+  Msg(DIRECT, "  versions; it is their choice whether to do so. The GNU General");
+  Msg(DIRECT, "  Public License gives permission to release a modified version");
+  Msg(DIRECT, "  without this exception; this exception also makes it possible to");
+  Msg(DIRECT, "  release a modified version which carries forward this exception.");
+  Msg(DIRECT, " ");
+  Msg(DIRECT, "End of exception.");
+  Msg(DIRECT, " ");
   Msg(DIRECT, "		    GNU GENERAL PUBLIC LICENSE");
   Msg(DIRECT, "		       Version 2, June 1991");
   Msg(DIRECT, " ");
   Msg(DIRECT, " Copyright (C) 1989, 1991 Free Software Foundation, Inc.");
-  Msg(DIRECT, "                       59 Temple Place, Suite 330, Boston, MA  02111-1307  USA");
+  Msg(DIRECT, " 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA");
   Msg(DIRECT, " Everyone is permitted to copy and distribute verbatim copies");
   Msg(DIRECT, " of this license document, but changing it is not allowed.");
   Msg(DIRECT, " ");
