@@ -1,6 +1,6 @@
-// $Id: OS.cpp,v 1.4 2006/03/03 12:40:21 geuzaine Exp $
+// $Id: OS.cpp,v 1.8 2007-05-23 15:35:33 geuzaine Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -91,6 +91,23 @@ void GetResources(double *s, long *mem)
 #endif
 }
 
+void CheckResources(){
+#if !defined (WIN32) || defined(__CYGWIN__)
+  static struct rlimit r;
+
+  getrlimit(RLIMIT_STACK, &r);
+
+  // Try to get at least 16 MB of stack. Running with too small a stack
+  // can cause crashes in the recursive calls (e.g. for tet
+  // classification in 3D Delaunay)
+  if(r.rlim_cur < 16 * 1024 * 1024){
+    Msg(INFO, "Increasing process stack size (%d kB < 16 MB)", r.rlim_cur / 1024);
+    r.rlim_cur = r.rlim_max;
+    setrlimit(RLIMIT_STACK, &r);
+  }
+#endif
+}
+
 double Cpu()
 {
   long mem = 0;
@@ -143,7 +160,7 @@ int KillProcess(int pid)
   return 1;
 }
 
-void SystemCall(char *command)
+int SystemCall(char *command)
 {
 #if defined(WIN32)
   STARTUPINFO suInfo;
@@ -153,12 +170,13 @@ void SystemCall(char *command)
   Msg(INFO, "Calling '%s'", command);
   CreateProcess(NULL, command, NULL, NULL, FALSE,
                 NORMAL_PRIORITY_CLASS, NULL, NULL, &suInfo, &prInfo);
+  return 0;
 #else
   if(!system(NULL)) {
     Msg(GERROR, "Could not find /bin/sh: aborting system call");
-    return;
+    return 1;
   }
   Msg(INFO, "Calling '%s'", command);
-  system(command);
+  return system(command);
 #endif
 }
