@@ -1,7 +1,7 @@
 #ifndef _OS_H_
 #define _OS_H_
 
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -23,11 +23,12 @@
 double GetTimeInSeconds();
 void SleepInSeconds(double s);
 void GetResources(double *s, long *mem);
+void CheckResources();
 double Cpu();
 int GetProcessId();
 int UnlinkFile(char *name);
 int StatFile(char *filename);
 int KillProcess(int pid);
-void SystemCall(char *command);
+int SystemCall(char *command);
 
 #endif
