@@ -1,7 +1,7 @@
 #ifndef _OPTIONS_H_
 #define _OPTIONS_H_
 
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -51,7 +51,7 @@ char * opt_general_session_filename(OPT_ARGS_STR);
 char * opt_general_options_filename(OPT_ARGS_STR);
 char * opt_general_editor(OPT_ARGS_STR);
 char * opt_general_web_browser(OPT_ARGS_STR);
-char * opt_general_scheme(OPT_ARGS_STR);
+char * opt_general_gui_theme(OPT_ARGS_STR);
 char * opt_general_graphics_font(OPT_ARGS_STR);
 char * opt_mesh_triangle_options(OPT_ARGS_STR);
 char * opt_solver_socket_name(OPT_ARGS_STR);
@@ -249,6 +249,10 @@ double opt_general_message_size0(OPT_ARGS_NUM);
 double opt_general_message_size1(OPT_ARGS_NUM);
 double opt_general_option_position0(OPT_ARGS_NUM);
 double opt_general_option_position1(OPT_ARGS_NUM);
+double opt_general_plugin_position0(OPT_ARGS_NUM);
+double opt_general_plugin_position1(OPT_ARGS_NUM);
+double opt_general_plugin_size0(OPT_ARGS_NUM);
+double opt_general_plugin_size1(OPT_ARGS_NUM);
 double opt_general_statistics_position0(OPT_ARGS_NUM);
 double opt_general_statistics_position1(OPT_ARGS_NUM);
 double opt_general_visibility_position0(OPT_ARGS_NUM);
@@ -257,7 +261,6 @@ double opt_general_clip_position0(OPT_ARGS_NUM);
 double opt_general_clip_position1(OPT_ARGS_NUM);
 double opt_general_manip_position0(OPT_ARGS_NUM);
 double opt_general_manip_position1(OPT_ARGS_NUM);
-double opt_general_visibility_mode(OPT_ARGS_NUM);
 double opt_general_session_save(OPT_ARGS_NUM);
 double opt_general_options_save(OPT_ARGS_NUM);
 double opt_general_rotation0(OPT_ARGS_NUM);
@@ -292,6 +295,12 @@ double opt_general_orthographic(OPT_ARGS_NUM);
 double opt_general_mouse_selection(OPT_ARGS_NUM);
 double opt_general_draw_bounding_box(OPT_ARGS_NUM);
 double opt_general_fast_redraw(OPT_ARGS_NUM);
+double opt_general_xmin(OPT_ARGS_NUM);
+double opt_general_xmax(OPT_ARGS_NUM);
+double opt_general_ymin(OPT_ARGS_NUM);
+double opt_general_ymax(OPT_ARGS_NUM);
+double opt_general_zmin(OPT_ARGS_NUM);
+double opt_general_zmax(OPT_ARGS_NUM);
 double opt_general_axes(OPT_ARGS_NUM);
 double opt_general_axes_auto_position(OPT_ARGS_NUM);
 double opt_general_axes_xmin(OPT_ARGS_NUM);
@@ -309,6 +318,7 @@ double opt_general_small_axes_position1(OPT_ARGS_NUM);
 double opt_general_small_axes_size(OPT_ARGS_NUM);
 double opt_general_quadric_subdivisions(OPT_ARGS_NUM);
 double opt_general_double_buffer(OPT_ARGS_NUM);
+double opt_general_antialiasing(OPT_ARGS_NUM);
 double opt_general_alpha_blending(OPT_ARGS_NUM);
 double opt_general_vector_type(OPT_ARGS_NUM);
 double opt_general_arrow_head_radius(OPT_ARGS_NUM);
@@ -379,6 +389,8 @@ double opt_general_light51(OPT_ARGS_NUM);
 double opt_general_light52(OPT_ARGS_NUM);
 double opt_general_light53(OPT_ARGS_NUM);
 double opt_geometry_auto_coherence(OPT_ARGS_NUM);
+double opt_geometry_highlight_orphans(OPT_ARGS_NUM);
+double opt_geometry_tolerance(OPT_ARGS_NUM);
 double opt_geometry_normals(OPT_ARGS_NUM);
 double opt_geometry_tangents(OPT_ARGS_NUM);
 double opt_geometry_points(OPT_ARGS_NUM);
@@ -389,30 +401,33 @@ double opt_geometry_points_num(OPT_ARGS_NUM);
 double opt_geometry_lines_num(OPT_ARGS_NUM);
 double opt_geometry_surfaces_num(OPT_ARGS_NUM);
 double opt_geometry_volumes_num(OPT_ARGS_NUM);
-double opt_mesh_points_per_element(OPT_ARGS_NUM);
 double opt_geometry_point_size(OPT_ARGS_NUM);
 double opt_geometry_point_sel_size(OPT_ARGS_NUM);
 double opt_geometry_point_type(OPT_ARGS_NUM);
 double opt_geometry_line_width(OPT_ARGS_NUM);
-double opt_mesh_label_frequency(OPT_ARGS_NUM);
 double opt_geometry_line_sel_width(OPT_ARGS_NUM);
 double opt_geometry_line_type(OPT_ARGS_NUM);
 double opt_geometry_light(OPT_ARGS_NUM);
+double opt_geometry_occ_fix_small_edges(OPT_ARGS_NUM);
+double opt_geometry_occ_fix_small_faces(OPT_ARGS_NUM);
+double opt_geometry_occ_sew_faces(OPT_ARGS_NUM);
 double opt_geometry_old_circle(OPT_ARGS_NUM);
 double opt_geometry_old_newreg(OPT_ARGS_NUM);
 double opt_geometry_circle_points(OPT_ARGS_NUM);
 double opt_geometry_extrude_spline_points(OPT_ARGS_NUM);
+double opt_geometry_extrude_return_lateral(OPT_ARGS_NUM);
 double opt_geometry_scaling_factor(OPT_ARGS_NUM);
 double opt_geometry_snap0(OPT_ARGS_NUM);
 double opt_geometry_snap1(OPT_ARGS_NUM);
 double opt_geometry_snap2(OPT_ARGS_NUM);
+double opt_mesh_label_frequency(OPT_ARGS_NUM);
 double opt_mesh_optimize(OPT_ARGS_NUM);
-double opt_mesh_quality(OPT_ARGS_NUM);
 double opt_mesh_normals(OPT_ARGS_NUM);
 double opt_mesh_tangents(OPT_ARGS_NUM);
 double opt_mesh_explode(OPT_ARGS_NUM);
 double opt_mesh_scaling_factor(OPT_ARGS_NUM);
 double opt_mesh_lc_factor(OPT_ARGS_NUM);
+double opt_mesh_lc_from_curvature(OPT_ARGS_NUM);
 double opt_mesh_rand_factor(OPT_ARGS_NUM);
 double opt_mesh_quality_inf(OPT_ARGS_NUM);
 double opt_mesh_quality_sup(OPT_ARGS_NUM);
@@ -422,6 +437,12 @@ double opt_mesh_radius_sup(OPT_ARGS_NUM);
 double opt_mesh_label_type(OPT_ARGS_NUM);
 double opt_mesh_points(OPT_ARGS_NUM);
 double opt_mesh_lines(OPT_ARGS_NUM);
+double opt_mesh_triangles(OPT_ARGS_NUM);
+double opt_mesh_quadrangles(OPT_ARGS_NUM);
+double opt_mesh_tetrahedra(OPT_ARGS_NUM);
+double opt_mesh_hexahedra(OPT_ARGS_NUM);
+double opt_mesh_prisms(OPT_ARGS_NUM);
+double opt_mesh_pyramids(OPT_ARGS_NUM);
 double opt_mesh_surfaces_edges(OPT_ARGS_NUM);
 double opt_mesh_surfaces_faces(OPT_ARGS_NUM);
 double opt_mesh_volumes_edges(OPT_ARGS_NUM);
@@ -433,8 +454,8 @@ double opt_mesh_volumes_num(OPT_ARGS_NUM);
 double opt_mesh_point_size(OPT_ARGS_NUM);
 double opt_mesh_point_type(OPT_ARGS_NUM);
 double opt_mesh_line_width(OPT_ARGS_NUM);
-double opt_mesh_line_type(OPT_ARGS_NUM);
 double opt_mesh_vertex_arrays(OPT_ARGS_NUM);
+double opt_mesh_reverse_all_normals(OPT_ARGS_NUM);
 double opt_mesh_smooth_normals(OPT_ARGS_NUM);
 double opt_mesh_angle_smooth_normals(OPT_ARGS_NUM);
 double opt_mesh_light(OPT_ARGS_NUM);
@@ -442,36 +463,30 @@ double opt_mesh_light_lines(OPT_ARGS_NUM);
 double opt_mesh_light_two_side(OPT_ARGS_NUM);
 double opt_mesh_format(OPT_ARGS_NUM);
 double opt_mesh_msh_file_version(OPT_ARGS_NUM);
-double opt_mesh_renumber_nodes_continuous(OPT_ARGS_NUM);
+double opt_mesh_msh_binary(OPT_ARGS_NUM);
+double opt_mesh_stl_binary(OPT_ARGS_NUM);
+double opt_mesh_bdf_field_format(OPT_ARGS_NUM);
 double opt_mesh_nb_smoothing(OPT_ARGS_NUM);
-double opt_mesh_stl_distance_tol(OPT_ARGS_NUM);
-double opt_mesh_nb_elem_per_rc(OPT_ARGS_NUM);
-double opt_mesh_min_elem_size_fact(OPT_ARGS_NUM);
-double opt_mesh_target_elem_size_fact(OPT_ARGS_NUM);
-double opt_mesh_beta_smooth_metric(OPT_ARGS_NUM);
-double opt_mesh_dihedral_angle_tol(OPT_ARGS_NUM);
-double opt_mesh_edge_prolongation_threshold(OPT_ARGS_NUM);
-double opt_mesh_nb_partitions(OPT_ARGS_NUM);
 double opt_mesh_algo2d(OPT_ARGS_NUM);
-double opt_mesh_recombine_algo(OPT_ARGS_NUM);
 double opt_mesh_algo3d(OPT_ARGS_NUM);
-double opt_mesh_point_insertion(OPT_ARGS_NUM);
-double opt_mesh_speed_max(OPT_ARGS_NUM);
+double opt_mesh_recombine_algo(OPT_ARGS_NUM);
 double opt_mesh_min_circ_points(OPT_ARGS_NUM);
 double opt_mesh_constrained_bgmesh(OPT_ARGS_NUM);
 double opt_mesh_order(OPT_ARGS_NUM);
+double opt_mesh_c1(OPT_ARGS_NUM);
+double opt_mesh_smooth_internal_edges(OPT_ARGS_NUM);
+double opt_mesh_second_order_linear(OPT_ARGS_NUM);
+double opt_mesh_second_order_incomplete(OPT_ARGS_NUM);
 double opt_mesh_dual(OPT_ARGS_NUM);
-double opt_mesh_initial_only(OPT_ARGS_NUM);
-double opt_mesh_interactive(OPT_ARGS_NUM);
 double opt_mesh_use_cut_plane(OPT_ARGS_NUM);
-double opt_mesh_cut_plane_as_surface(OPT_ARGS_NUM);
+double opt_mesh_cut_plane_draw_intersect(OPT_ARGS_NUM);
 double opt_mesh_cut_plane_only_volume(OPT_ARGS_NUM);
 double opt_mesh_cut_planea(OPT_ARGS_NUM);
 double opt_mesh_cut_planeb(OPT_ARGS_NUM);
 double opt_mesh_cut_planec(OPT_ARGS_NUM);
 double opt_mesh_cut_planed(OPT_ARGS_NUM);
-double opt_mesh_allow_degenerated_extrude(OPT_ARGS_NUM);
 double opt_mesh_save_all(OPT_ARGS_NUM);
+double opt_mesh_save_groups_of_nodes(OPT_ARGS_NUM);
 double opt_mesh_color_carousel(OPT_ARGS_NUM);
 double opt_mesh_nb_nodes(OPT_ARGS_NUM);
 double opt_mesh_nb_triangles(OPT_ARGS_NUM);
@@ -627,10 +642,13 @@ double opt_print_eps_line_width_factor(OPT_ARGS_NUM);
 double opt_print_eps_point_size_factor(OPT_ARGS_NUM);
 double opt_print_jpeg_quality(OPT_ARGS_NUM);
 double opt_print_jpeg_smoothing(OPT_ARGS_NUM);
+double opt_print_geo_labels(OPT_ARGS_NUM);
 double opt_print_gif_dither(OPT_ARGS_NUM);
 double opt_print_gif_sort(OPT_ARGS_NUM);
 double opt_print_gif_interlace(OPT_ARGS_NUM);
 double opt_print_gif_transparent(OPT_ARGS_NUM);
+double opt_print_text(OPT_ARGS_NUM);
+double opt_print_tex_as_equation(OPT_ARGS_NUM);
 
 // COLORS
 
@@ -647,14 +665,14 @@ unsigned int opt_geometry_color_points(OPT_ARGS_COL);
 unsigned int opt_geometry_color_lines(OPT_ARGS_COL);
 unsigned int opt_geometry_color_surfaces(OPT_ARGS_COL);
 unsigned int opt_geometry_color_volumes(OPT_ARGS_COL);
-unsigned int opt_geometry_color_points_select(OPT_ARGS_COL);
-unsigned int opt_geometry_color_lines_select(OPT_ARGS_COL);
-unsigned int opt_geometry_color_surfaces_select(OPT_ARGS_COL);
-unsigned int opt_geometry_color_volumes_select(OPT_ARGS_COL);
+unsigned int opt_geometry_color_selection(OPT_ARGS_COL);
+unsigned int opt_geometry_color_highlight0(OPT_ARGS_COL);
+unsigned int opt_geometry_color_highlight1(OPT_ARGS_COL);
+unsigned int opt_geometry_color_highlight2(OPT_ARGS_COL);
 unsigned int opt_geometry_color_tangents(OPT_ARGS_COL);
 unsigned int opt_geometry_color_normals(OPT_ARGS_COL);
 unsigned int opt_mesh_color_points(OPT_ARGS_COL); 
-unsigned int opt_mesh_color_points_deg2(OPT_ARGS_COL); 
+unsigned int opt_mesh_color_points_sup(OPT_ARGS_COL); 
 unsigned int opt_mesh_color_lines(OPT_ARGS_COL); 
 unsigned int opt_mesh_color_triangles(OPT_ARGS_COL);
 unsigned int opt_mesh_color_quadrangles(OPT_ARGS_COL);
