@@ -1,7 +1,7 @@
 #ifndef _CALLBACKS_H_
 #define _CALLBACKS_H_
 
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -42,7 +42,8 @@ void status_xyz1p_cb(CALLBACK_ARGS);
 void status_play_cb(CALLBACK_ARGS);
 void status_pause_cb(CALLBACK_ARGS);
 void status_rewind_cb(CALLBACK_ARGS);
-void status_cancel_cb(CALLBACK_ARGS);
+void status_stepbackward_cb(CALLBACK_ARGS);
+void status_stepforward_cb(CALLBACK_ARGS);
 
 // File Menu
 
@@ -81,12 +82,11 @@ void options_cb(CALLBACK_ARGS);
 void options_browser_cb(CALLBACK_ARGS);
 void options_save_cb(CALLBACK_ARGS);
 void options_restore_defaults_cb(CALLBACK_ARGS);
-void options_ok_cb(CALLBACK_ARGS);
 
 void general_options_cb(CALLBACK_ARGS);
+void general_options_ok_cb(CALLBACK_ARGS);
 void general_options_color_scheme_cb(CALLBACK_ARGS);
 void general_options_rotation_center_select_cb(CALLBACK_ARGS);
-void general_options_ok_cb(CALLBACK_ARGS);
 void general_arrow_param_cb(CALLBACK_ARGS);
 
 void geometry_options_cb(CALLBACK_ARGS);
@@ -94,8 +94,6 @@ void geometry_options_ok_cb(CALLBACK_ARGS);
 
 void mesh_options_cb(CALLBACK_ARGS);
 void mesh_options_ok_cb(CALLBACK_ARGS);
-void mesh_cut_plane_cb(CALLBACK_ARGS);
-void mesh_cut_plane_invert_cb(CALLBACK_ARGS);
 
 void solver_options_cb(CALLBACK_ARGS);
 void solver_options_ok_cb(CALLBACK_ARGS);
@@ -103,6 +101,12 @@ void solver_options_ok_cb(CALLBACK_ARGS);
 void post_options_cb(CALLBACK_ARGS);
 void post_options_ok_cb(CALLBACK_ARGS);
 
+void view_options_cb(CALLBACK_ARGS);
+void view_options_ok_cb(CALLBACK_ARGS);
+void view_options_timestep_cb(CALLBACK_ARGS);
+void view_options_timestep_decr_cb(CALLBACK_ARGS);
+void view_options_timestep_incr_cb(CALLBACK_ARGS);
+void view_arrow_param_cb(CALLBACK_ARGS);
 void view_toggle_cb(CALLBACK_ARGS);
 void view_reload_cb(CALLBACK_ARGS);
 void view_reload_all_cb(CALLBACK_ARGS);
@@ -129,15 +133,10 @@ void view_combine_time_visible_cb(CALLBACK_ARGS);
 void view_combine_time_by_name_cb(CALLBACK_ARGS);
 void view_all_visible_cb(CALLBACK_ARGS);
 void view_applybgmesh_cb(CALLBACK_ARGS);
-void view_plugin_options_cb(CALLBACK_ARGS);
+void view_plugin_cb(CALLBACK_ARGS);
+void view_plugin_browser_cb(CALLBACK_ARGS);
+void view_plugin_run_cb(CALLBACK_ARGS);
 void view_plugin_cancel_cb(CALLBACK_ARGS);
-void view_options_cb(CALLBACK_ARGS);
-void view_options_timestep_cb(CALLBACK_ARGS);
-void view_options_timestep_decr_cb(CALLBACK_ARGS);
-void view_options_timestep_incr_cb(CALLBACK_ARGS);
-void view_options_custom_set_cb(CALLBACK_ARGS);
-void view_options_ok_cb(CALLBACK_ARGS);
-void view_arrow_param_cb(CALLBACK_ARGS);
 
 // Statistics Menu
 
@@ -157,7 +156,10 @@ void message_save_cb(CALLBACK_ARGS);
 void visibility_cb(CALLBACK_ARGS);
 void visibility_sort_cb(CALLBACK_ARGS);
 void visibility_number_cb(CALLBACK_ARGS);
+void visibility_interactive_cb(CALLBACK_ARGS);
 void visibility_ok_cb(CALLBACK_ARGS);
+void visibility_save_cb(CALLBACK_ARGS);
+void visibility_delete_cb(CALLBACK_ARGS);
 
 // Clipping planes Menu
 
@@ -272,10 +274,13 @@ void mesh_define_cb(CALLBACK_ARGS);
 void mesh_1d_cb(CALLBACK_ARGS);
 void mesh_2d_cb(CALLBACK_ARGS); 
 void mesh_3d_cb(CALLBACK_ARGS); 
-void mesh_stl_cb(CALLBACK_ARGS);
+void mesh_edit_cb(CALLBACK_ARGS);
+void mesh_delete_cb(CALLBACK_ARGS);
+void mesh_delete_parts_cb(CALLBACK_ARGS);
+void mesh_inspect_cb(CALLBACK_ARGS);
 void mesh_remesh_cb(CALLBACK_ARGS); 
 void mesh_update_edges_cb(CALLBACK_ARGS); 
-void mesh_update_more_edges_cb(CALLBACK_ARGS);
+void mesh_parameterize_cb(CALLBACK_ARGS);
 void mesh_degree_cb(CALLBACK_ARGS); 
 void mesh_optimize_cb(CALLBACK_ARGS); 
 void mesh_define_length_cb (CALLBACK_ARGS);
@@ -284,7 +289,6 @@ void mesh_define_transfinite_cb (CALLBACK_ARGS);
 void mesh_define_transfinite_line_cb(CALLBACK_ARGS);
 void mesh_define_transfinite_surface_cb(CALLBACK_ARGS);
 void mesh_define_transfinite_volume_cb(CALLBACK_ARGS); 
-void mesh_define_elliptic_surface_cb(CALLBACK_ARGS);
 
 // Dynamic Solver Menus
 
