@@ -1,6 +1,6 @@
-// $Id: Colorbar_Window.cpp,v 1.50 2006/01/06 00:34:22 geuzaine Exp $
+// $Id: Colorbar_Window.cpp,v 1.58 2007-06-12 07:04:08 geuzaine Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@
 
 extern Context_T CTX;
 
-#define EPS         1.e-10
+#define EPS 1.e-10
 
 // This file defines the Colorbar_Window class (subclass of Fl_Window)
 
@@ -45,7 +45,7 @@ Colorbar_Window::Colorbar_Window(int x, int y, int w, int h, const char *l)
   ct = NULL;
   label = NULL;
   help_flag = 1;
-  font_height = CTX.fontsize;
+  font_height = GetFontSize();
   marker_height = font_height;
   wedge_height = marker_height;
   marker_pos = 0;
@@ -314,16 +314,16 @@ void Colorbar_Window::redraw_marker()
 
 void Colorbar_Window::draw()
 {
-  if(ct) {
-    label_y = h() - 5;
-    marker_y = label_y - marker_height - font_height;
-    wedge_y = marker_y - wedge_height;
-    color_bg = fl_color_cube(CTX.UNPACK_RED(CTX.color.bg) * FL_NUM_RED / 256,
-                             CTX.UNPACK_GREEN(CTX.color.bg) * FL_NUM_GREEN / 256,
-                             CTX.UNPACK_BLUE(CTX.color.bg) * FL_NUM_BLUE / 256);
-    redraw_range(0, ct->size - 1);
-    redraw_marker();
-  }
+  if(!ct) return;
+
+  label_y = h() - 5;
+  marker_y = label_y - marker_height - font_height;
+  wedge_y = marker_y - wedge_height;
+  color_bg = fl_color_cube(CTX.UNPACK_RED(CTX.color.bg) * FL_NUM_RED / 256,
+			   CTX.UNPACK_GREEN(CTX.color.bg) * FL_NUM_GREEN / 256,
+			   CTX.UNPACK_BLUE(CTX.color.bg) * FL_NUM_BLUE / 256);
+  redraw_range(0, ct->size - 1);
+  redraw_marker();
 }
 
 // Update
@@ -343,6 +343,8 @@ void Colorbar_Window::update(char *name, double min, double max,
 
 int Colorbar_Window::handle(int event)
 {
+  if(!ct) return Fl_Window::handle(event);
+
   static int p1 = 0, p2 = 0, p3 = 0, p4 = 0;
   static int pentry, move_marker;
   int i, ibut, xpos, ypos, modify, entry, compute;
@@ -450,12 +452,12 @@ int Colorbar_Window::handle(int event)
     }
     else if(Fl::test_shortcut(FL_CTRL + 'v')) {
       ColorTable_Paste(ct);
-      draw();
+      redraw();
       *viewchanged = 1;
     }
     else if(Fl::test_shortcut('h')) {
       help_flag = !help_flag;
-      draw();
+      redraw();
     }
     else if(Fl::test_shortcut('r')) {
       ColorTable_InitParam(ct->ipar[COLORTABLE_NUMBER], ct);
@@ -466,7 +468,7 @@ int Colorbar_Window::handle(int event)
         ct->ipar[COLORTABLE_MODE] = COLORTABLE_HSV;
       else
         ct->ipar[COLORTABLE_MODE] = COLORTABLE_RGB;
-      draw();
+      redraw();
     }
     else if(Fl::test_shortcut('i')) {
       ct->ipar[COLORTABLE_SWAP] = !ct->ipar[COLORTABLE_SWAP];
@@ -542,9 +544,9 @@ int Colorbar_Window::handle(int event)
 
     if(compute) {
       ColorTable_Recompute(ct);
-      draw();
+      redraw();
       *viewchanged = 1;
-      set_changed();
+      do_callback();
     }
     return 1;
 
@@ -554,7 +556,7 @@ int Colorbar_Window::handle(int event)
     ypos = Fl::event_y();
     if(help_flag) {
       help_flag = 0;
-      draw();
+      redraw();
     }
     // change color function or marker position
     if(ypos < wedge_y)
@@ -584,6 +586,7 @@ int Colorbar_Window::handle(int event)
     p2 = 0;
     p3 = 0;
     p4 = 0;
+    if(*viewchanged) do_callback();
     break;
 
   case FL_DRAG:
@@ -613,12 +616,7 @@ int Colorbar_Window::handle(int event)
     else {
       // changing color graph
       int a, b, value;
-
-      *viewchanged = 1;
-      set_changed();
-
       value = y_to_intensity(ypos);
-
       if(pentry <= entry) {
         a = pentry;
         b = entry;
@@ -627,63 +625,41 @@ int Colorbar_Window::handle(int event)
         a = entry;
         b = pentry;
       }
-
       // update entries from 'pentry' to 'entry'
       for(i = a; i <= b; i++) {
         int red, green, blue, alpha;
         double R, G, B, H, S, V;
-
         red = CTX.UNPACK_RED(ct->table[i]);
         green = CTX.UNPACK_GREEN(ct->table[i]);
         blue = CTX.UNPACK_BLUE(ct->table[i]);
         alpha = CTX.UNPACK_ALPHA(ct->table[i]);
-
         if(ct->ipar[COLORTABLE_MODE] == COLORTABLE_RGB) {
-          if(p1) {
-            red = value;
-          }
-          if(p2) {
-            green = value;
-          }
-          if(p3) {
-            blue = value;
-          }
-          if(p4) {
-            alpha = value;
-          }
+          if(p1) red = value;
+          if(p2) green = value;
+          if(p3) blue = value;
+          if(p4) alpha = value;
         }
         else if(ct->ipar[COLORTABLE_MODE] == COLORTABLE_HSV) {
           RGB_to_HSV((double)red / 255., (double)green / 255.,
                      (double)blue / 255., &H, &S, &V);
-          if(p1) {
-            H = 6. * (double)value / 255. + EPS;
-          }
-          if(p2) {
-            S = (double)value / 255.;
-          }
-          if(p3) {
-            V = (double)value / 255.;
-          }
-          if(p4) {
-            alpha = value;
-          }
+          if(p1) H = 6. * (double)value / 255. + EPS;
+          if(p2) S = (double)value / 255.;
+          if(p3) V = (double)value / 255.;
+          if(p4) alpha = value;
           HSV_to_RGB(H, S, V, &R, &G, &B);
           red = (int)(255 * R);
           green = (int)(255 * G);
           blue = (int)(255 * B);
         }
-
         ct->table[i] = CTX.PACK_COLOR(red, green, blue, alpha);
       }
-
       // redraw the color curves
       if(pentry < entry)
         redraw_range(pentry - 1, entry + 1);
       else
         redraw_range(entry - 1, pentry + 1);
-
       pentry = entry;
-
+      *viewchanged = 1;
     }
     return 1;
   }
