@@ -1,7 +1,7 @@
 #ifndef _GUI_EXTRAS_H_
 #define _GUI_EXTRAS_H_
 
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -29,11 +29,18 @@ void file_chooser_get_position(int *x, int *y);
 int arrow_editor(char *title, double &a, double &b, double &c);
 int perspective_editor();
 
-int jpeg_dialog(char *filename, int TeX);
+int jpeg_dialog(char *filename);
 int gif_dialog(char *filename);
-int gl2ps_dialog(char *filename, char *title, int format, int TeX);
+int geo_dialog(char *filename);
+int generic_bitmap_dialog(char *filename, char *title, int format);
+int generic_mesh_dialog(char *filename, char *title, int format);
+int gl2ps_dialog(char *filename, char *title, int format);
 int options_dialog(char *filename);
 int msh_dialog(char *filename);
+int unv_dialog(char *filename);
+int bdf_dialog(char *filename);
+int stl_dialog(char *filename);
+int latex_dialog(char *filename);
 
 #endif
 
