@@ -1,6 +1,6 @@
-// $Id: Main.cpp,v 1.87.2.1 2006/03/17 21:16:37 geuzaine Exp $
+// $Id: Main.cpp,v 1.107 2007-04-21 19:40:00 geuzaine Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -19,30 +19,33 @@
 // 
 // Please report all bugs and problems to <gmsh@geuz.org>.
 
-#include <iostream>
-#include <vector>
 #include <signal.h>
 #include <time.h>
 
 #include "GUI.h"
-#include "PluginManager.h"
 #include "Gmsh.h"
 #include "GmshUI.h"
+#include "OS.h"
 #include "Geo.h"
-#include "Mesh.h"
+#include "Generator.h"
+#include "CreateFile.h"
 #include "Draw.h"
 #include "Context.h"
 #include "Options.h"
-#include "ColorTable.h"
 #include "Parser.h"
 #include "OpenFile.h"
 #include "CommandLine.h"
 #include "Numeric.h"
 #include "Solvers.h"
+#include "PluginManager.h"
+#include "GModel.h"
+#include "Field.h"
+#include "BackgroundMesh.h"
 
 Context_T CTX;
-Mesh M, *THEM = NULL;
-GUI *WID = NULL;
+Mesh *THEM = 0;
+GUI *WID = 0;
+GModel *GMODEL = 0;
 
 int main(int argc, char *argv[])
 {
@@ -66,14 +69,14 @@ int main(int argc, char *argv[])
     strcat(cmdline, " ");
   }
 
+  // Create a new model
+  GMODEL = new GModel;
+  THEM = new Mesh;
+
   // Initialize the symbol tree that will hold variable names
   
   InitSymbols();
 
-  // Initialize the static Mesh
-  
-  Init_Mesh0(&M);
-
   // Gmsh default options
 
   Init_Options(0);
@@ -105,6 +108,8 @@ int main(int argc, char *argv[])
   signal(SIGFPE, Signal);
 #endif
 
+  CheckResources();
+  
   // Initialize the default plugins
 
   GMSH_PluginManager::instance()->registerDefaultPlugins();
@@ -114,33 +119,34 @@ int main(int argc, char *argv[])
   if(CTX.batch) {
     check_gsl();
     Msg(INFO, "'%s' started on %s", cmdline, currtime);
-    OpenProblem(CTX.filename);
+    OpenProject(CTX.filename);
     if(yyerrorstate)
       exit(1);
     else {
       for(int i = 1; i < List_Nbr(CTX.files); i++)
-        MergeProblem(*(char**)List_Pointer(CTX.files, i));
+        MergeFile(*(char**)List_Pointer(CTX.files, i));
       if(CTX.post.combine_time)
 	CombineViews(1, 2, CTX.post.combine_remove_orig);
       if(CTX.bgm_filename) {
-        MergeProblem(CTX.bgm_filename);
-        if(List_Nbr(CTX.post.list))
-          BGMWithView(*(Post_View **)
-                      List_Pointer(CTX.post.list,
-                                   List_Nbr(CTX.post.list) - 1));
+        MergeFile(CTX.bgm_filename);
+        if(List_Nbr(CTX.post.list)){
+	  Post_View *v;
+	  List_Read(CTX.post.list, List_Nbr(CTX.post.list) - 1, &v);
+	  Field *field = new PostViewField(v);
+	  BGMAddField(field);
+	  fields.insert(field);
+        }
         else
           Msg(GERROR, "Invalid background mesh (no view)");
       }
       if(CTX.batch > 0) {
-        mai3d(THEM, CTX.batch);
-        Print_Mesh(THEM, CTX.output_filename, CTX.mesh.format);
-      }
-      else
-        Print_Geo(THEM, CTX.output_filename);
-      if(CTX.mesh.histogram) {
-        Mesh_Quality(THEM);
-        Print_Histogram(THEM->Histogram[0]);
+        GenerateMesh(CTX.batch);
+        CreateOutputFile(CTX.output_filename, CTX.mesh.format);
       }
+      else if(CTX.batch == -1)
+        CreateOutputFile(CTX.output_filename, FORMAT_GEO);
+      else if(CTX.batch == -2)
+	GMODEL->checkMeshCoherence();
       exit(0);
     }
   }
@@ -164,8 +170,8 @@ int main(int argc, char *argv[])
 
   // Say welcome!
 
-  Msg(STATUS3N, "Ready");
-  Msg(STATUS1N, "Gmsh %s", Get_GmshVersion());
+  Msg(STATUS1N, "Geometry");
+  Msg(STATUS2N, "Gmsh %s", Get_GmshVersion());
 
   // Log the following for bug reports
 
@@ -193,9 +199,9 @@ int main(int argc, char *argv[])
 
   // Open project file and merge all other input files
 
-  OpenProblem(CTX.filename);
+  OpenProject(CTX.filename);
   for(int i = 1; i < List_Nbr(CTX.files); i++)
-    MergeProblem(*(char**)List_Pointer(CTX.files, i));
+    MergeFile(*(char**)List_Pointer(CTX.files, i));
   if(CTX.post.combine_time)
     CombineViews(1, 2, CTX.post.combine_remove_orig);
   
@@ -225,10 +231,14 @@ int main(int argc, char *argv[])
   // Read background mesh on disk
 
   if(CTX.bgm_filename) {
-    MergeProblem(CTX.bgm_filename);
-    if(List_Nbr(CTX.post.list))
-      BGMWithView(*(Post_View **)
-                  List_Pointer(CTX.post.list, List_Nbr(CTX.post.list) - 1));
+    MergeFile(CTX.bgm_filename);
+    if(List_Nbr(CTX.post.list)){
+      Post_View *v;
+      List_Read(CTX.post.list, List_Nbr(CTX.post.list) - 1, &v);
+      Field *field = new PostViewField(v);
+      BGMAddField(field);
+      fields.insert(field);
+    }
     else
       Msg(GERROR, "Invalid background mesh (no view)");
   }
