@@ -1,6 +1,6 @@
-// $Id: Opengl.cpp,v 1.57 2006/01/06 00:34:23 geuzaine Exp $
+// $Id: Opengl.cpp,v 1.73 2007-06-22 08:07:46 geuzaine Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -23,25 +23,25 @@
 #include "GmshUI.h"
 #include "Numeric.h"
 #include "Context.h"
-#include "Geo.h"
-#include "Mesh.h"
 #include "Draw.h"
+#include "SelectBuffer.h"
 #include "GUI.h"
 #include "gl2ps.h"
 
 extern GUI *WID;
-extern Mesh M;
 extern Context_T CTX;
 
 // Draw specialization
 
 void SetOpenglContext(void)
 {
+  if(!WID) return;
   WID->make_opengl_current();
 }
 
 void Draw(void)
 {
+  if(!WID) return;
   WID->redraw_opengl();
 }
 
@@ -53,6 +53,9 @@ void SanitizeTeXString(char *in, char *out)
     strcpy(out, in);
     return;
   }
+
+  if(CTX.print.tex_as_equation) *out++ = '$';
+
   // otherwise, escape the following special characters:
   char bad[8] = { '%', '^', '#', '%', '&', '_', '{', '}' };
   while(*in){
@@ -64,48 +67,48 @@ void SanitizeTeXString(char *in, char *out)
     }
     *out++ = *in++;
   }
+
+  if(CTX.print.tex_as_equation) *out++ = '$';
+
   *out = '\0';
 }
 
 void Draw_String(char *s, char *font_name, int font_enum, int font_size, int align)
 {
-  if(align > 0){
-    // change the raster position only if not creating TeX files
-    if(CTX.print.gl_fonts || (CTX.print.format != FORMAT_TEX)){
-      GLboolean valid;
-      glGetBooleanv(GL_CURRENT_RASTER_POSITION_VALID, &valid);
-      if(valid == GL_TRUE){
-	GLdouble pos[4];
-	glGetDoublev(GL_CURRENT_RASTER_POSITION, pos);
-	double x[3], w[3] = {pos[0], pos[1], pos[2]};
-	gl_font(font_enum, font_size);
-	float width = gl_width(s);
-	float height = gl_height();
-	switch(align){
-	case 1: w[0] -= width/2.;                     break; // bottom center
-	case 2: w[0] -= width;                        break; // bottom right
-	case 3:                    w[1] -= height;    break; // top left
-	case 4: w[0] -= width/2.;  w[1] -= height;    break; // top center
-	case 5: w[0] -= width;     w[1] -= height;    break; // top right
-	case 6:                    w[1] -= height/2.; break; // center left
-	case 7: w[0] -= width/2.;  w[1] -= height/2.; break; // center center
-	case 8: w[0] -= width;     w[1] -= height/2.; break; // center right
-	default: break;
-	}
-	Viewport2World(w, x);
-	glRasterPos3d(x[0], x[1], x[2]);
+  if(CTX.printing && !CTX.print.text) return;
+
+  // change the raster position only if not creating TeX files
+  if(align > 0 && (!CTX.printing || CTX.print.format != FORMAT_TEX)){
+    GLboolean valid;
+    glGetBooleanv(GL_CURRENT_RASTER_POSITION_VALID, &valid);
+    if(valid == GL_TRUE){
+      GLdouble pos[4];
+      glGetDoublev(GL_CURRENT_RASTER_POSITION, pos);
+      double x[3], w[3] = {pos[0], pos[1], pos[2]};
+      gl_font(font_enum, font_size);
+      float width = gl_width(s);
+      float height = gl_height();
+      switch(align){
+      case 1: w[0] -= width/2.;                     break; // bottom center
+      case 2: w[0] -= width;                        break; // bottom right
+      case 3:                    w[1] -= height;    break; // top left
+      case 4: w[0] -= width/2.;  w[1] -= height;    break; // top center
+      case 5: w[0] -= width;     w[1] -= height;    break; // top right
+      case 6:                    w[1] -= height/2.; break; // center left
+      case 7: w[0] -= width/2.;  w[1] -= height/2.; break; // center center
+      case 8: w[0] -= width;     w[1] -= height/2.; break; // center right
+      default: break;
       }
+      Viewport2World(w, x);
+      glRasterPos3d(x[0], x[1], x[2]);
     }
   }
   
-  if(CTX.print.gl_fonts) {
+  if(!CTX.printing){
     gl_font(font_enum, font_size);
     gl_draw(s);
   }
-  else { // ps, pdf or *tex output
-    if(CTX.print.format == FORMAT_JPEGTEX ||
-       CTX.print.format == FORMAT_PNGTEX)
-      return;
+  else{
     if(CTX.print.format == FORMAT_TEX){
       char tmp[1024];
       SanitizeTeXString(s, tmp);
@@ -123,8 +126,16 @@ void Draw_String(char *s, char *font_name, int font_enum, int font_size, int ali
       }
       gl2psTextOpt(tmp, font_name, font_size, opt, 0.);
     }
-    else
+    else if(CTX.print.eps_quality && (CTX.print.format == FORMAT_PS ||
+				      CTX.print.format == FORMAT_EPS ||
+				      CTX.print.format == FORMAT_PDF ||
+				      CTX.print.format == FORMAT_SVG)){
       gl2psText(s, font_name, font_size);
+    }
+    else{
+      gl_font(font_enum, font_size);
+      gl_draw(s);
+    }
   }
 }
 
@@ -163,6 +174,8 @@ void Draw_String(char *s, double style)
 
 void Draw_OnScreenMessages()
 {
+  if(!WID) return;
+
   glColor4ubv((GLubyte *) & CTX.color.text);
   gl_font(CTX.gl_font_enum, CTX.gl_fontsize);
   double h = gl_height();
@@ -181,11 +194,15 @@ void Draw_OnScreenMessages()
 
 // Select entity routine
 
-char SelectEntity(int type, int *n,
-		  Vertex *v[SELECTION_MAX_HITS], 
-		  Curve *c[SELECTION_MAX_HITS], 
-		  Surface *s[SELECTION_MAX_HITS])
+char SelectEntity(int type, 
+		  std::vector<GVertex*> &vertices,
+		  std::vector<GEdge*> &edges,
+		  std::vector<GFace*> &faces,
+		  std::vector<GRegion*> &regions,
+		  std::vector<MElement*> &elements)
 {
+  if(!WID) return 'q';
+
   WID->g_opengl_window->take_focus(); // force keyboard focus in GL window 
   WID->g_opengl_window->SelectionMode = true; // enable lasso selection
 
@@ -194,15 +211,14 @@ char SelectEntity(int type, int *n,
   WID->quit_selection = 0;
   WID->end_selection = 0;
   WID->undo_selection = 0;
+  WID->invert_selection = 0;
 
   while(1) {
-    *n = 0;
-    for(int i = 0; i < SELECTION_MAX_HITS; i++){
-      v[i] = NULL;
-      c[i] = NULL;
-      s[i] = NULL;
-    }
-
+    vertices.clear();
+    edges.clear();
+    faces.clear();
+    regions.clear();
+    elements.clear();
     WID->wait();
     if(WID->quit_selection) {
       WID->selection = ENT_NONE;
@@ -223,35 +239,25 @@ char SelectEntity(int type, int *n,
     }
     if(WID->try_selection) {
       bool add = (WID->try_selection > 0) ? true : false;
-      bool multi = (WID->try_selection > 1) ? true : false;
+      bool multi = (abs(WID->try_selection) > 1) ? true : false;
       WID->try_selection = 0;
       if(WID->selection == ENT_NONE){ // just report the mouse click
 	WID->g_opengl_window->SelectionMode = false;
 	return 'c';
       }
-      else{
-	*n = Process_SelectionBuffer(WID->selection, multi,
+      else if(ProcessSelectionBuffer(WID->selection, multi, true,
 				     WID->try_selection_xywh[0],
 				     WID->try_selection_xywh[1], 
 				     WID->try_selection_xywh[2],
 				     WID->try_selection_xywh[3], 
-				     v, c, s, &M);
-	if(*n){
-	  if(add){
-	    for(int i = 0; i < *n; i++)
-	      HighlightEntity(v[i], c[i], s[i], 1);
-	    Draw();
-	  }
-	  // don't call ZeroHighlight here if we (try to) deselect:
-	  // deselection is not supported in all cases, so it's better
-	  // to de-highlight the entities in the callback
-	  WID->selection = ENT_NONE;
-	  WID->g_opengl_window->SelectionMode = false;
-	  if(add)
-	    return 'l';
-	  else
-	    return 'r';
-	}
+				     vertices, edges, faces, regions,
+				     elements)){
+	WID->selection = ENT_NONE;
+	WID->g_opengl_window->SelectionMode = false;
+	if(add)
+	  return 'l';
+	else
+	  return 'r';
       }
     }
   }
