@@ -1,6 +1,6 @@
-// $Id: Opengl_Window.cpp,v 1.60 2006/01/18 16:19:10 geuzaine Exp $
+// $Id: Opengl_Window.cpp,v 1.78 2006-12-17 22:23:16 geuzaine Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -24,13 +24,12 @@
 #include "GmshUI.h"
 #include "Context.h"
 #include "Geo.h"
-#include "Mesh.h"
 #include "Draw.h"
+#include "SelectBuffer.h"
 #include "GUI.h"
 #include "Opengl_Window.h"
 
 extern GUI *WID;
-extern Mesh M;
 extern Context_T CTX;
 
 void MousePosition::set()
@@ -179,11 +178,6 @@ void Opengl_Window::draw()
 
 int Opengl_Window::handle(int event)
 {
-  Vertex *v[SELECTION_MAX_HITS];
-  Curve *c[SELECTION_MAX_HITS];
-  Surface *s[SELECTION_MAX_HITS];
-  double dx, dy;
-
   switch (event) {
 
   case FL_FOCUS: // accept the focus when I'm asked if I want it
@@ -229,14 +223,24 @@ int Opengl_Window::handle(int event)
     }
     else if(Fl::event_button() == 2 || 
 	    (Fl::event_button() == 1 && Fl::event_state(FL_SHIFT))) {
-      if(Fl::event_state(FL_CTRL) && !LassoMode) {
+      if(!LassoMode && Fl::event_state(FL_CTRL)) {
 	// make zoom isotropic
         CTX.s[1] = CTX.s[0];
         CTX.s[2] = CTX.s[0];
         redraw();
       }
       else if(LassoMode) {
-        LassoMode = false;
+	LassoMode = false;
+	if(SelectionMode && CTX.enable_mouse_selection){
+	  WID->try_selection = -2; // will try to unselect multiple entities
+	  WID->try_selection_xywh[0] = (int)(click.win[0] + curr.win[0])/2;
+	  WID->try_selection_xywh[1] = (int)(click.win[1] + curr.win[1])/2;
+	  WID->try_selection_xywh[2] = (int)fabs(click.win[0] - curr.win[0]);
+	  WID->try_selection_xywh[3] = (int)fabs(click.win[1] - curr.win[1]);
+	}
+	else{
+	  lasso_zoom(click, curr);
+	}
       }
       else if(CTX.enable_mouse_selection){
         WID->try_selection = -1; // will try to unselect clicked entity
@@ -267,6 +271,7 @@ int Opengl_Window::handle(int event)
 
   case FL_RELEASE:
     curr.set();
+    CTX.draw_rotation_center = 0;
     if(!LassoMode) {
       CTX.mesh.draw = 1;
       CTX.post.draw = 1;
@@ -275,48 +280,72 @@ int Opengl_Window::handle(int event)
     prev.set();
     return 1;
 
-  case FL_DRAG:
-    curr.set();
-    dx = curr.win[0] - prev.win[0];
-    dy = curr.win[1] - prev.win[1];
-    if(LassoMode) {
+  case FL_MOUSEWHEEL:
+    {
+      double dy = Fl::event_dy();
+      double fact = (5. * CTX.zoom_factor * fabs(dy) + h()) / (double)h();
+      CTX.s[0] *= ((dy > 0) ? fact : 1./fact);
+      CTX.s[1] = CTX.s[0];
+      CTX.s[2] = CTX.s[0];
+      prev.recenter();
       redraw();
     }
-    else {
-      if(Fl::event_button() == 1 && 
-	 !Fl::event_state(FL_SHIFT) && !Fl::event_state(FL_ALT)) {
-        if(CTX.useTrackball)
-          CTX.addQuaternion((2. * prev.win[0] - w()) / w(),
-                            (h() - 2. * prev.win[1]) / h(),
-                            (2. * curr.win[0] - w()) / w(),
-                            (h() - 2. * curr.win[1]) / h());
-        else {
-          CTX.r[1] += ((fabs(dx) > fabs(dy)) ? 180. * dx / (double)w() : 0.);
-	  CTX.r[0] += ((fabs(dx) > fabs(dy)) ? 0. : 180. * dy / (double)h());
-        }
-      }
-      else if(Fl::event_button() == 2 ||
-	      (Fl::event_button() == 1 && Fl::event_state(FL_SHIFT))) {
-        if(fabs(dy) > fabs(dx)) {
-	  double fact = (CTX.zoom_factor * fabs(dy) + h()) / (double)h();
-	  CTX.s[0] *= ((dy > 0) ? fact : 1./fact);
-	  CTX.s[1] = CTX.s[0];
-	  CTX.s[2] = CTX.s[0];
-	  click.recenter();
-	}
-	else if(!CTX.useTrackball)
-          CTX.r[2] += -180. * dx / (double)w();
+    WID->update_manip_window();
+    return 1;
+
+  case FL_DRAG:
+    curr.set();
+    {
+      double dx = curr.win[0] - prev.win[0];
+      double dy = curr.win[1] - prev.win[1];
+      if(LassoMode) {
+	redraw();
       }
       else {
-        CTX.t[0] += (curr.wnr[0] - click.wnr[0]);
-	CTX.t[1] += (curr.wnr[1] - click.wnr[1]);
-        CTX.t[2] = 0.;
+	if(Fl::event_state(FL_META)) {
+	  // will try to select or unselect entities on the fly
+	  WID->try_selection = Fl::event_state(FL_SHIFT) ? -1 : 1; 
+	  WID->try_selection_xywh[0] = (int)curr.win[0];
+	  WID->try_selection_xywh[1] = (int)curr.win[1];
+	  WID->try_selection_xywh[2] = 5;
+	  WID->try_selection_xywh[3] = 5;
+	}
+	else if(Fl::event_button() == 1 && 
+		!Fl::event_state(FL_SHIFT) && !Fl::event_state(FL_ALT)) {
+	  if(CTX.useTrackball)
+	    CTX.addQuaternion((2. * prev.win[0] - w()) / w(),
+			      (h() - 2. * prev.win[1]) / h(),
+			      (2. * curr.win[0] - w()) / w(),
+			      (h() - 2. * curr.win[1]) / h());
+	  else {
+	    CTX.r[1] += ((fabs(dx) > fabs(dy)) ? 180. * dx / (double)w() : 0.);
+	    CTX.r[0] += ((fabs(dx) > fabs(dy)) ? 0. : 180. * dy / (double)h());
+	  }
+	}
+	else if(Fl::event_button() == 2 ||
+		(Fl::event_button() == 1 && Fl::event_state(FL_SHIFT))) {
+	  if(fabs(dy) > fabs(dx)) {
+	    double fact = (CTX.zoom_factor * fabs(dy) + h()) / (double)h();
+	    CTX.s[0] *= ((dy > 0) ? fact : 1./fact);
+	    CTX.s[1] = CTX.s[0];
+	    CTX.s[2] = CTX.s[0];
+	    click.recenter();
+	  }
+	  else if(!CTX.useTrackball)
+	    CTX.r[2] += -180. * dx / (double)w();
+	}
+	else {
+	  CTX.t[0] += (curr.wnr[0] - click.wnr[0]);
+	  CTX.t[1] += (curr.wnr[1] - click.wnr[1]);
+	  CTX.t[2] = 0.;
+	}
+	CTX.draw_rotation_center = 1;
+	if(CTX.fast_redraw) {
+	  CTX.mesh.draw = 0;
+	  CTX.post.draw = 0;
+	}
+	redraw();
       }
-      if(CTX.fast_redraw) {
-        CTX.mesh.draw = 0;
-        CTX.post.draw = 0;
-      }
-      redraw();
     }
     prev.set();
     WID->update_manip_window();
@@ -331,7 +360,7 @@ int Opengl_Window::handle(int event)
       WID->g_opengl_window->cursor(FL_CURSOR_CROSS, FL_BLACK, FL_WHITE);
       // find line in real space corresponding to current cursor position
       double p[3],d[3];
-      unproject(curr.win[0], curr.win[1], p, d);
+      Unproject(curr.win[0], curr.win[1], p, d);
       // fin closest point to the center of gravity
       double r[3] = {CTX.cg[0] - p[0], CTX.cg[1] - p[1], CTX.cg[2] - p[2]}, t;
       prosca(r, d, &t);
@@ -351,20 +380,36 @@ int Opengl_Window::handle(int event)
       sprintf(str, "%g", point[2]); WID->context_geometry_input[4]->value(str);
       redraw();
     }
-    else if(CTX.enable_mouse_selection >= 2){ // hover mode
+    else{ // hover mode
       if(curr.win[0] != prev.win[0] || curr.win[1] != prev.win[1]){
 	WID->make_opengl_current();
-	v[0] = NULL; c[0] = NULL; s[0] = NULL;
-	Process_SelectionBuffer(WID->selection, 0, 
-				(int)curr.win[0], (int)curr.win[1], 5, 5, 
-				v, c, s, &M);
-	if((WID->selection == ENT_POINT && v[0]) ||
-	   (WID->selection == ENT_LINE && c[0]) || 
-	   (WID->selection == ENT_SURFACE && s[0]))
+	std::vector<GVertex*> vertices;
+	std::vector<GEdge*> edges;
+	std::vector<GFace*> faces;
+	std::vector<GRegion*> regions;
+	std::vector<MElement*> elements;
+	bool something = ProcessSelectionBuffer(WID->selection, false,
+						CTX.enable_mouse_selection > 1,
+						(int)curr.win[0], (int)curr.win[1], 5, 5, 
+						vertices, edges, faces, regions,
+						elements);
+	if((WID->selection == ENT_ALL && something) ||
+	   (WID->selection == ENT_POINT && vertices.size()) ||
+	   (WID->selection == ENT_LINE && edges.size()) || 
+	   (WID->selection == ENT_SURFACE && faces.size()) ||
+	   (WID->selection == ENT_VOLUME && regions.size()))
 	  WID->g_window->cursor(FL_CURSOR_CROSS, FL_BLACK, FL_WHITE);
 	else
 	  WID->g_window->cursor(FL_CURSOR_DEFAULT, FL_BLACK, FL_WHITE);
-	HighlightEntity(v[0], c[0], s[0], 0);
+	GEntity *ge = 0;
+	if(vertices.size()) ge = vertices[0];
+	else if(edges.size()) ge = edges[0];
+	else if(faces.size()) ge = faces[0];
+	else if(regions.size()) ge = regions[0];
+	MElement *me = elements.size() ? elements[0] : 0;
+	Msg(STATUS2N, "%s %s",
+	    ge ? ge->getInfoString().c_str() : "", 
+	    me ? me->getInfoString().c_str() : "");
       }
     }
     prev.set();
