@@ -1,6 +1,6 @@
-// $Id: Draw.cpp,v 1.95 2006/01/16 17:55:43 geuzaine Exp $
+// $Id: Draw.cpp,v 1.109 2006-11-27 22:22:14 geuzaine Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -21,24 +21,21 @@
 
 #include "Gmsh.h"
 #include "GmshUI.h"
-#include "Geo.h"
-#include "CAD.h"
-#include "Mesh.h"
+#include "GmshDefines.h"
 #include "Draw.h"
 #include "Context.h"
 #include "Numeric.h"
+#include "GModel.h"
 
 extern Context_T CTX;
-extern Mesh M;
-
-// Global Draw functions
+extern GModel *GMODEL;
 
 int NeedPolygonOffset()
 {
-  if(M.status == 2 &&
+  if(GMODEL->getMeshStatus() == 2 &&
      (CTX.mesh.surfaces_edges || CTX.geom.lines || CTX.geom.surfaces))
     return 1;
-  if(M.status == 3 && 
+  if(GMODEL->getMeshStatus() == 3 && 
      (CTX.mesh.surfaces_edges || CTX.mesh.volumes_edges))
     return 1;
   for(int i = 0; i < List_Nbr(CTX.post.list); i++){
@@ -77,8 +74,9 @@ void Draw3d(void)
   InitProjection();
   InitRenderModel();
   InitPosition();
-
-  Draw_Mesh(&M);
+  Draw_Geom();
+  Draw_Mesh();
+  Draw_Post();
 }
 
 void Draw2d(void)
@@ -130,8 +128,6 @@ void ClearOpengl(void)
   glClear(GL_DEPTH_BUFFER_BIT | GL_COLOR_BUFFER_BIT);
 }
 
-// Init
-
 void InitProjection(int xpick, int ypick, int wpick, int hpick)
 {
   double Va = 
@@ -260,6 +256,11 @@ void InitRenderModel(void)
 {
   GLfloat r, g, b;
 
+  glPushMatrix();
+  glLoadIdentity();
+  glScaled(CTX.s[0], CTX.s[1], CTX.s[2]);
+  glTranslated(CTX.t[0], CTX.t[1], CTX.t[2]);
+  
   for(int i = 0; i < 6; i++) {
     if(CTX.light[i]) {
       GLfloat position[4] = {(GLfloat)CTX.light_position[i][0],
@@ -293,6 +294,8 @@ void InitRenderModel(void)
     }
   }
 
+  glPopMatrix();
+
   // ambient and diffuse material colors track glColor automatically
   glColorMaterial(GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE);
   glEnable(GL_COLOR_MATERIAL);
@@ -344,129 +347,16 @@ void InitPosition(void)
   // context has changed, i.e., even if we are out of Draw())
   glGetDoublev(GL_PROJECTION_MATRIX, CTX.proj);
   glGetDoublev(GL_MODELVIEW_MATRIX, CTX.model);
-}
 
-// Entity selection
-
-typedef struct{
-  unsigned int type, ient, depth;
-} hit;
-
-int fcmp_hit_depth(const void *a, const void *b)
-{
-  return ((hit*)a)->depth - ((hit*)b)->depth;
-}
-
-int Process_SelectionBuffer(int type, bool multi,
-			    int x, int y, int w, int h,
-			    Vertex *v[SELECTION_MAX_HITS],
-			    Curve *c[SELECTION_MAX_HITS],
-			    Surface *s[SELECTION_MAX_HITS],
-			    Mesh *m)
-{
-  hit hits[SELECTION_BUFFER_SIZE];
-  GLuint selectBuf[SELECTION_BUFFER_SIZE];
-
-  glSelectBuffer(SELECTION_BUFFER_SIZE, selectBuf);
-
-  glRenderMode(GL_SELECT);
-  CTX.render_mode = GMSH_SELECT;
-
-  glInitNames();
-  glPushMatrix();
-  InitProjection(x, y, w, h);
-  InitPosition();
-  Draw_Mesh(&M);
-  glPopMatrix();
-
-  GLint numhits = glRenderMode(GL_RENDER);
-  CTX.render_mode = GMSH_RENDER;
-
-  if(!numhits){ // no hits
-    return 0;
-  }
-  else if(numhits < 0){ // overflow
-    Msg(WARNING, "Selection buffer size exceeded");
-    return 0;
-  }
-
-  GLint *ptr = (GLint *) selectBuf;
-
-  int numentities = 0;
-  for(int i = 0; i < numhits; i++) {
-    GLint names = *ptr++; 
-    GLint mindepth = *ptr++;
-    GLint maxdepth = *ptr++;
-    // in Gmsh 'names' should always be 2 (in which case the first is
-    // the type of the entity (0=point, 1=line, ...) and the second
-    // the entity number) or 0 (if there is nothing in the stack)
-    if(names == 2){
-      hits[numentities].depth = (mindepth+maxdepth)/2;
-      hits[numentities].type = *ptr++; 
-      hits[numentities].ient = *ptr++;
-      numentities++;
-    }
-  }
-
-  if(!numentities){ // no entities
-    return 0;
-  }
-
-  // filter result: if type == ENT_NONE, return the closest entity of
-  // "lowest dimension" (point < line < surface < volume). Otherwise,
-  // return the closest entity of type "type"
-
-  unsigned int typmin = 4;
-  for(int i = 0; i < numentities; i++) {
-    if(hits[i].type < typmin)
-      typmin = hits[i].type;
-  }
-
-  // sort hits to get closest entities first
-  qsort(hits, numentities, sizeof(hit), fcmp_hit_depth);
-  
-  int j = 0;
-  for(int i = 0; i < numentities; i++) {
-    if((type == ENT_NONE && hits[i].type == typmin) ||
-       (type == ENT_POINT && hits[i].type == 0) ||
-       (type == ENT_LINE && hits[i].type == 1) ||
-       (type == ENT_SURFACE && hits[i].type == 2)){
-      switch (hits[i].type) {
-      case 0:
-	if(!(v[j] = FindPoint(hits[i].ient, m))){
-	  Msg(GERROR, "Problem in point selection processing");
-	  return j;
-	}
-	j++;
-	if(!multi) return 1;
-	break;
-      case 1:
-	if(!(c[j] = FindCurve(hits[i].ient, m))){
-	  Msg(GERROR, "Problem in line selection processing");
-	  return j;
-	}
-	j++;
-	if(!multi) return 1;
-	break;
-      case 2:
-	if(!(s[j] = FindSurface(hits[i].ient, m))){
-	  Msg(GERROR, "Problem in surface selection processing");
-	  return j;
-	}
-	j++;
-	if(!multi) return 1;
-	break;
-      }
-    }
-  }
-  return j;
+  for(int i = 0; i < 6; i++)
+    glClipPlane((GLenum)(GL_CLIP_PLANE0 + i), CTX.clip_plane[i]);
 }
 
 // Takes a cursor position in window coordinates and returns the line
 // (given by a point and a unit direction vector), in real space, that
 // corresponds to that cursor position
 
-void unproject(double x, double y, double p[3], double d[3])
+void Unproject(double x, double y, double p[3], double d[3])
 {
   GLint viewport[4];
   glGetIntegerv(GL_VIEWPORT, viewport);
