@@ -1,6 +1,6 @@
-// $Id: Entity.cpp,v 1.63 2006/01/20 00:29:59 geuzaine Exp $
+// $Id: Entity.cpp,v 1.72 2007-06-22 12:08:16 remacle Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -19,8 +19,6 @@
 // 
 // Please report all bugs and problems to <gmsh@geuz.org>.
 
-
-#include "Mesh.h"
 #include "Gmsh.h"
 #include "GmshUI.h"
 #include "Numeric.h"
@@ -130,7 +128,7 @@ void Draw_Cylinder(double width, double *x, double *y, double *z, int light)
 void Draw_Line(int type, double width, double *x, double *y, double *z,
                int light)
 {
-  if(type)
+  if(type==1)
     Draw_Cylinder(width, x, y, z, light);
   else {
     glBegin(GL_LINES);
@@ -140,6 +138,25 @@ void Draw_Line(int type, double width, double *x, double *y, double *z,
   }
 }
 
+void Draw_Triangle_Overlay(double r, double g, double b,
+			   double *v1, double *v2, double *v3)
+{
+  SetOpenglContext();
+  InitProjection();
+  InitPosition();
+  glDisable(GL_DEPTH_TEST);
+  glDrawBuffer(GL_FRONT);
+  glColor3f(r, g, b);
+  glBegin(GL_LINE_LOOP);
+  glVertex3dv(v1);
+  glVertex3dv(v2);
+  glVertex3dv(v3);
+  glEnd();
+  glFlush();
+  glDrawBuffer(GL_BACK);
+  glEnable(GL_DEPTH_TEST);
+}
+
 void Draw_SimpleVector(int arrow, int fill,
 		       double relHeadRadius, double relStemLength, double relStemRadius,
 		       double x, double y, double z,
@@ -437,6 +454,48 @@ public:
     };
 };
 
+void Draw_Box(double xmin, double ymin, double zmin,
+	      double xmax, double ymax, double zmax,
+	      bool labels)
+{
+  glBegin(GL_LINE_LOOP);
+  glVertex3d(xmin, ymin, zmin);
+  glVertex3d(xmax, ymin, zmin);
+  glVertex3d(xmax, ymax, zmin);
+  glVertex3d(xmin, ymax, zmin);
+  glEnd();
+  glBegin(GL_LINE_LOOP);
+  glVertex3d(xmin, ymin, zmax);
+  glVertex3d(xmax, ymin, zmax);
+  glVertex3d(xmax, ymax, zmax);
+  glVertex3d(xmin, ymax, zmax);
+  glEnd();
+  glBegin(GL_LINES);
+  glVertex3d(xmin, ymin, zmin);
+  glVertex3d(xmin, ymin, zmax);
+  glVertex3d(xmax, ymin, zmin);
+  glVertex3d(xmax, ymin, zmax);
+  glVertex3d(xmax, ymax, zmin);
+  glVertex3d(xmax, ymax, zmax);
+  glVertex3d(xmin, ymax, zmin);
+  glVertex3d(xmin, ymax, zmax);
+  glEnd();
+  if(labels){
+    char label[256];
+    double offset = 0.3 * CTX.gl_fontsize * CTX.pixel_equiv_x;
+    glRasterPos3d(xmin + offset / CTX.s[0], 
+		  ymin + offset / CTX.s[1], 
+		  zmin + offset / CTX.s[2]);
+    sprintf(label, "(%g,%g,%g)", xmin, ymin, zmin);
+    Draw_String(label);
+    glRasterPos3d(xmax + offset / CTX.s[0], 
+		  ymax + offset / CTX.s[1], 
+		  zmax + offset / CTX.s[2]);
+    sprintf(label, "(%g,%g,%g)", xmax, ymax, zmax);
+    Draw_String(label);
+  }
+}
+
 void Draw_PlaneInBoundingBox(double xmin, double ymin, double zmin,
 			     double xmax, double ymax, double zmax,
 			     double a, double b, double c, double d,
@@ -532,7 +591,7 @@ void Draw_PlaneInBoundingBox(double xmin, double ymin, double zmin,
 void Draw_SmallAxes()
 {
   double l = CTX.small_axes_size;
-  double o = 2;
+  double o = CTX.gl_fontsize / 5;
 
   double cx = CTX.small_axes_pos[0];
   double cy = CTX.small_axes_pos[1];
@@ -573,7 +632,7 @@ int Draw_Tics(int comp, int n, char *format, char *label,
   double t[3] = { p2[0]-p1[0], p2[1]-p1[1], p2[2]-p1[2] };
   double l = norme(t);
   double w = 10 * CTX.pixel_equiv_x / CTX.s[0]; // big tics 10 pixels
-  double w2 = 4 * CTX.pixel_equiv_x / CTX.s[0]; // small tics 4 pixels
+  double w2 = 5 * CTX.pixel_equiv_x / CTX.s[0]; // small tics 5 pixels
 
   glRasterPos3d(p2[0]+t[0]*w*1.4, p2[1]+t[1]*w*1.4, p2[2]+t[2]*w*1.4);
   Draw_String(label);
