@@ -1,6 +1,6 @@
-// $Id: Post.cpp,v 1.105 2006/02/14 15:13:18 geuzaine Exp $
+// $Id: Post.cpp,v 1.113 2006-11-27 22:22:16 geuzaine Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -22,8 +22,6 @@
 #include "Gmsh.h"
 #include "GmshUI.h"
 #include "Numeric.h"
-#include "Geo.h"
-#include "Mesh.h"
 #include "Draw.h"
 #include "Views.h"
 #include "Context.h"
@@ -470,50 +468,23 @@ void Draw_Post(void)
   double ValMin = 0., ValMax = 0.;
   Post_View *v;
 
+  // draw any plugin-specific stuff
+  if(CTX.post.plugin_draw_function)
+    (*CTX.post.plugin_draw_function)();
+
   if(!CTX.post.list)
     return;
 
-  if(CTX.draw_bbox || !CTX.post.draw) {  // draw only the bbox of the visible views
+  if(CTX.draw_bbox || !CTX.post.draw) {
     for(int iView = 0; iView < List_Nbr(CTX.post.list); iView++) {
       v = *(Post_View **) List_Pointer(CTX.post.list, iView);
+      // draw only the bbox of visible 3D views
       if(v->Visible && v->Type == DRAW_POST_3D) {
         glColor4ubv((GLubyte *) & CTX.color.fg);
 	glLineWidth(CTX.line_width);
-        glBegin(GL_LINE_LOOP);
-        glVertex3d(v->BBox[0], v->BBox[2], v->BBox[4]);
-        glVertex3d(v->BBox[1], v->BBox[2], v->BBox[4]);
-        glVertex3d(v->BBox[1], v->BBox[3], v->BBox[4]);
-        glVertex3d(v->BBox[0], v->BBox[3], v->BBox[4]);
-        glEnd();
-        glBegin(GL_LINE_LOOP);
-        glVertex3d(v->BBox[0], v->BBox[2], v->BBox[5]);
-        glVertex3d(v->BBox[1], v->BBox[2], v->BBox[5]);
-        glVertex3d(v->BBox[1], v->BBox[3], v->BBox[5]);
-        glVertex3d(v->BBox[0], v->BBox[3], v->BBox[5]);
-        glEnd();
-        glBegin(GL_LINES);
-        glVertex3d(v->BBox[0], v->BBox[2], v->BBox[4]);
-        glVertex3d(v->BBox[0], v->BBox[2], v->BBox[5]);
-        glVertex3d(v->BBox[1], v->BBox[2], v->BBox[4]);
-        glVertex3d(v->BBox[1], v->BBox[2], v->BBox[5]);
-        glVertex3d(v->BBox[1], v->BBox[3], v->BBox[4]);
-        glVertex3d(v->BBox[1], v->BBox[3], v->BBox[5]);
-        glVertex3d(v->BBox[0], v->BBox[3], v->BBox[4]);
-        glVertex3d(v->BBox[0], v->BBox[3], v->BBox[5]);
-        glEnd();
-	char label[256];
-	double offset = 0.5 * CTX.gl_fontsize * CTX.pixel_equiv_x;
-	glRasterPos3d(v->BBox[0] + offset / CTX.s[0], 
-		      v->BBox[2] + offset / CTX.s[0], 
-		      v->BBox[4] + offset / CTX.s[0]);
-	sprintf(label, "(%g,%g,%g)", v->BBox[0], v->BBox[2], v->BBox[4]);
-	Draw_String(label);
-	glRasterPos3d(v->BBox[1] + offset / CTX.s[0], 
-		      v->BBox[3] + offset / CTX.s[0], 
-		      v->BBox[5] + offset / CTX.s[0]);
-	sprintf(label, "(%g,%g,%g)", v->BBox[1], v->BBox[3], v->BBox[5]);
-	Draw_String(label);
-
+	gl2psLineWidth(CTX.line_width * CTX.print.eps_line_width_factor);
+	Draw_Box(v->BBox[0], v->BBox[2], v->BBox[4],
+		 v->BBox[1], v->BBox[3], v->BBox[5]);
 	glColor3d(1.,0.,0.);
 	for(int i = 0; i < 6; i++)
 	  if(CTX.clip[i] & (1<<(2+iView)))
@@ -778,25 +749,27 @@ void Draw_Post(void)
 
       pass_1:
 	if(v->TriVertexArray && v->TriVertexArray->fill){
-	  Msg(DEBUG, "View[%d]; %d tris in vertex array", v->Index, v->TriVertexArray->num);
+	  Msg(DEBUG, "View[%d]; %d tris in vertex array", 
+	      v->Index, v->TriVertexArray->getNumVertices()/3);
 	  v->TriVertexArray->fill = 0;
 	}
 	if(v->LinVertexArray && v->LinVertexArray->fill){
-	  Msg(DEBUG, "View[%d]; %d segs in vertex array", v->Index, v->LinVertexArray->num);
+	  Msg(DEBUG, "View[%d]; %d segs in vertex array",
+	      v->Index, v->LinVertexArray->getNumVertices()/2);
 	  v->LinVertexArray->fill = 0;
 	}
       }
 
-      if(v->TriVertexArray && v->TriVertexArray->num){
+      if(v->TriVertexArray && v->TriVertexArray->getNumVertices()){
 	if(CTX.alpha && ColorTable_IsAlpha(&v->CT) && !v->FakeTransparency &&
 	   (changedEye() || v->Changed)){
 	  Msg(DEBUG, "Sorting View[%d] for transparency (WITH vertex array)", v->Index);
 	  v->TriVertexArray->sort(storedEye);
 	}
 
-	glVertexPointer(3, GL_FLOAT, 0, v->TriVertexArray->vertices->array);
-	glNormalPointer(GL_FLOAT, 0, v->TriVertexArray->normals->array);
-	glColorPointer(4, GL_UNSIGNED_BYTE, 0, v->TriVertexArray->colors->array);
+	glVertexPointer(3, GL_FLOAT, 0, v->TriVertexArray->getVertexArray());
+	glNormalPointer(GL_BYTE, 0, v->TriVertexArray->getNormalArray());
+	glColorPointer(4, GL_UNSIGNED_BYTE, 0, v->TriVertexArray->getColorArray());
 
 	glEnableClientState(GL_VERTEX_ARRAY);
 	glEnableClientState(GL_COLOR_ARRAY);
@@ -807,21 +780,21 @@ void Draw_Post(void)
 	else
 	  glDisableClientState(GL_NORMAL_ARRAY);
 	if(CTX.polygon_offset) glEnable(GL_POLYGON_OFFSET_FILL);
-	glDrawArrays(GL_TRIANGLES, 0, 3 * v->TriVertexArray->num);
+	glDrawArrays(GL_TRIANGLES, 0, v->TriVertexArray->getNumVertices());
 	glDisable(GL_POLYGON_OFFSET_FILL);
 	glDisable(GL_LIGHTING);
       
 	glDisableClientState(GL_VERTEX_ARRAY);
-	glDisableClientState(GL_COLOR_ARRAY);
 	glDisableClientState(GL_NORMAL_ARRAY);
+	glDisableClientState(GL_COLOR_ARRAY);
       }
 
-      if(v->LinVertexArray && v->LinVertexArray->num){
-	glVertexPointer(3, GL_FLOAT, 0, v->LinVertexArray->vertices->array);
-	glColorPointer(4, GL_UNSIGNED_BYTE, 0, v->LinVertexArray->colors->array);
+      if(v->LinVertexArray && v->LinVertexArray->getNumVertices()){
+	glVertexPointer(3, GL_FLOAT, 0, v->LinVertexArray->getVertexArray());
+	glColorPointer(4, GL_UNSIGNED_BYTE, 0, v->LinVertexArray->getColorArray());
 	glEnableClientState(GL_VERTEX_ARRAY);
 	glEnableClientState(GL_COLOR_ARRAY);
-	glDrawArrays(GL_LINES, 0, 2 * v->LinVertexArray->num);
+	glDrawArrays(GL_LINES, 0, v->LinVertexArray->getNumVertices());
 	glDisableClientState(GL_VERTEX_ARRAY);
 	glDisableClientState(GL_COLOR_ARRAY);
       }
