@@ -1,6 +1,6 @@
-// $Id: PostElement.cpp,v 1.71 2006/01/14 16:24:54 geuzaine Exp $
+// $Id: PostElement.cpp,v 1.79 2007-06-22 12:08:16 remacle Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -25,8 +25,6 @@
 
 #include "Gmsh.h"
 #include "GmshUI.h"
-#include "Geo.h"
-#include "Mesh.h"
 #include "Draw.h"
 #include "Iso.h"
 #include "Context.h"
@@ -466,11 +464,10 @@ void Draw_ScalarTriangle(Post_View * View, int preproNormals,
 	  View->TriVertexArray->add(X[i], Y[i], Z[i], 
 				    norms[3*i], norms[3*i+1], norms[3*i+2], col);
 	}
-	View->TriVertexArray->num++;
       }
       else{
 	if(View->Light) glEnable(GL_LIGHTING);
-	if(CTX.polygon_offset) glEnable(GL_POLYGON_OFFSET_FILL);
+	if(CTX.polygon_offset)
 	glBegin(GL_TRIANGLES);
 	for(int i = 0; i < 3; i++){
 	  PaletteContinuous(View, ValMin, ValMax, Val[i]);
@@ -511,7 +508,6 @@ void Draw_ScalarTriangle(Post_View * View, int preproNormals,
 	    col = PaletteContinuous(View, ValMin, ValMax, Vp[i]);
 	    View->TriVertexArray->add(Xp[i], Yp[i], Zp[i], 
 				      norms[3*i], norms[3*i+1], norms[3*i+2], col);
-	    View->TriVertexArray->num++;	    
 	  }
 	}
 	else{
@@ -565,7 +561,6 @@ void Draw_ScalarTriangle(Post_View * View, int preproNormals,
 					norms[3*(i-1)], norms[3*(i-1)+1], norms[3*(i-1)+2], col);
 	      View->TriVertexArray->add(Xp[i], Yp[i], Zp[i],
 					norms[3*i], norms[3*i+1], norms[3*i+2], col);
-	      View->TriVertexArray->num++;
 	    }
 	  }
 	  else{
@@ -1207,7 +1202,6 @@ void Draw_VectorPoint(ARGS)
 {
   Draw_VectorElement(POST_POINT, View, preproNormals, ValMin, ValMax, X, Y, Z, V);
 }
-
 void Draw_VectorLine(ARGS)
 {
   Draw_VectorElement(POST_LINE, View, preproNormals, ValMin, ValMax, X, Y, Z, V);
@@ -1247,12 +1241,15 @@ void Draw_VectorPyramid(ARGS)
 
 // Tensor Elements
 
+static int state = -1; // WTF? This is completely wrong when you have multiple view --CG
+
 void Draw_TensorElement(int type, Post_View * View, int preproNormals,
                         double ValMin, double ValMax,
-                        double *X, double *Y, double *Z, double *V)
+                        double *iX, double *iY, double *iZ, double *V)
 {
   int nbnod = 0;
 
+
   switch (type) {
   case POST_POINT: nbnod = 1; break;
   case POST_LINE: nbnod = 2; break;
@@ -1264,20 +1261,317 @@ void Draw_TensorElement(int type, Post_View * View, int preproNormals,
   case POST_PYRAMID: nbnod = 5; break;
   }
 
-  /// By lack of any current better solution, tensors are displayed as
-  /// their Von Mises invariant (J2 invariant); this will simply call
-  /// the scalar function...
-
-  // View->TensorType == DRAW_POST_VONMISES 
   int ts = View->TimeStep;
-  View->TimeStep = 0;
 
-  double V_VonMises[8];
-  for(int i = 0; i < nbnod; i++){
-    V_VonMises[i] = ComputeVonMises(V + 9*(i + nbnod * ts));
+  if(View->TensorType == DRAW_POST_VONMISES || !View->NbTP){
+
+    View->TimeStep = 0;
+    double V_VonMises[8];
+    for(int i = 0; i < nbnod; i++)
+      V_VonMises[i] = ComputeVonMises(V + 9*(i + nbnod * ts));
+    Draw_ScalarElement(type, View, preproNormals, ValMin, ValMax, 
+		       iX, iY, iZ, V_VonMises);
+
   }
+  else if(View->TensorType == DRAW_POST_LMGC90 || 
+	  View->TensorType == DRAW_POST_LMGC90_TYPE || 
+	  View->TensorType == DRAW_POST_LMGC90_COORD || 
+	  View->TensorType == DRAW_POST_LMGC90_PRES || 
+	  View->TensorType == DRAW_POST_LMGC90_SN || 
+	  View->TensorType == DRAW_POST_LMGC90_DEPX || 
+	  View->TensorType == DRAW_POST_LMGC90_DEPY|| 
+	  View->TensorType == DRAW_POST_LMGC90_DEPZ || 
+	  View->TensorType == DRAW_POST_LMGC90_DEPAV || 
+	  View->TensorType == DRAW_POST_LMGC90_DEPNORM){
+    
+    // FIXME: need to clean up this mess! --CG
+    
+    static double zmin[3], zmax[3];
+    int it;
+    double DEP[3];	// déplacement relatif cdf % a config de référence
+    double CDG[3];	// coordonnées du centre de gravité au tps t0
+    double ROT[3]; 	// angles de rotation du cdg % au repère absolu
+    double VAR[3];	// valeur des 3 variables supplémentaires
+    double X[3],Y[3],Z[3];
+    double ztmp[3];
+    
+    View->TimeStep = 0;
+    
+    List_T * list = (*(View->Grains))[(int)V[6]];
+    // Liste contenant toutes les info sur les lignes TP : (x,x,x) et {x,x,x,x,x,x,x,x,x, ...}
+    // info rangé à la suite
+    List_T * listt = View->TP;
+    
+    CDG[0] = iX[0];
+    CDG[1] = iY[0];
+    CDG[2] = iZ[0];
 
-  Draw_ScalarElement(type, View, preproNormals, ValMin, ValMax, X, Y, Z, V_VonMises);
+    // Lecture des coordonnées du cdg dans le repère absolu
+    //    List_Read(listt,0+it,&CDG[0]);
+    //    List_Read(listt,1+it,&CDG[1]);
+    //    List_Read(listt,2+it,&CDG[2]);
+    
+    // Lecture des déplacements par rapport au cdg initital
+
+    double *VV = V + 9* nbnod * ts ;
+
+    DEP[0] = VV[0];
+    DEP[1] = VV[1];
+    DEP[2] = VV[2];
+
+    //    List_Read(listt,3+ts*9+it,&DEP[0]);
+    //    List_Read(listt,4+ts*9+it,&DEP[1]);
+    //    List_Read(listt,5+ts*9+it,&DEP[2]);
+    
+    // Lecture des rotations du centre de gravité
+
+    ROT[0] = VV[3];
+    ROT[1] = VV[4];
+    ROT[2] = VV[5];
+
+    ///    List_Read(listt,6+ts*9+it,&ROT[0]);
+    //    List_Read(listt,7+ts*9+it,&ROT[1]);
+    //    List_Read(listt,8+ts*9+it,&ROT[2]);
+    
+    VAR[0] = VV[6];
+    VAR[1] = VV[7];
+    VAR[2] = VV[8];
+
+    // Lecture des valeurs des variables supplémentaires
+    //    List_Read(listt,9+ts*9+it,&VAR[0]);
+    //    List_Read(listt,10+ts*9+it,&VAR[1]);
+    //    List_Read(listt,11+ts*9+it,&VAR[2]);
+
+    // calcule les valeurs min et max d'une info 1 seule fois
+    if(state != View->TensorType)
+      {
+	printf("coucouc\n");
+	state = View->TensorType;
+	switch (View->TensorType) {
+	case DRAW_POST_LMGC90: 
+	  // couleur uniforme
+	  zmin[0]=1;
+	  zmax[0]=1;
+	  break;
+	case DRAW_POST_LMGC90_TYPE: 
+	  // couleur en fonction du type de grain
+	  it = List_Nbr(listt)/View->NbTP;
+	  List_Read(listt,9,&zmin[0]);
+	  List_Read(listt,9,&zmax[0]);
+	  for(int i = 0; i < View->NbTP; i++){
+	    List_Read(listt,i*it+9,&ztmp[0]);
+	    if(ztmp[0]<zmin[0]){zmin[0] = ztmp[0];}
+	    if(ztmp[0]>zmax[0]){zmax[0] = ztmp[0];}
+	  }
+	break;
+	case DRAW_POST_LMGC90_COORD: 
+	  it = List_Nbr(listt)/View->NbTP;
+	  List_Read(listt,9,&zmin[0]);
+	  List_Read(listt,9,&zmax[0]);
+	  for(int i = 0; i < View->NbTP; i++){
+	    for(int j = 0; j< ((List_Nbr(listt)/View->NbTP)-3)/9-1; j++){
+	      List_Read(listt,i*it+18+j*9,&ztmp[0]); // on part pas du premier
+	      if(ztmp[0]<zmin[0]){zmin[0] = ztmp[0];}
+	      if(ztmp[0]>zmax[0]){zmax[0] = ztmp[0];}
+	    }
+	  }
+	break;
+	case DRAW_POST_LMGC90_PRES: 
+	  it = List_Nbr(listt)/View->NbTP;
+	  List_Read(listt,10,&zmin[0]);
+	  List_Read(listt,10,&zmax[0]);
+	  for(int i = 0; i < View->NbTP; i++){
+	    for(int j = 0; j< ((List_Nbr(listt)/View->NbTP)-3)/9; j++){
+	      List_Read(listt,i*it+10+j*9,&ztmp[0]);
+	      if(ztmp[0]<zmin[0]){zmin[0] = ztmp[0];}
+	      if(ztmp[0]>zmax[0]){zmax[0] = ztmp[0];}
+	    }
+	  }
+	  break;
+	case DRAW_POST_LMGC90_SN: 
+	  it = List_Nbr(listt)/View->NbTP;
+	  List_Read(listt,11,&zmin[0]);
+	  List_Read(listt,11,&zmax[0]);
+	  for(int i = 0; i < View->NbTP; i++){
+	    for(int j = 0; j< ((List_Nbr(listt)/View->NbTP)-3)/9; j++){
+	      List_Read(listt,i*it+11+j*9,&ztmp[0]);
+	      if(ztmp[0]<zmin[0]){zmin[0] = ztmp[0];}
+	      if(ztmp[0]>zmax[0]){zmax[0] = ztmp[0];}
+	    }
+	  }
+	break;
+	case DRAW_POST_LMGC90_DEPX: 
+	  it = List_Nbr(listt)/View->NbTP;
+	  List_Read(listt,3,&zmin[0]);
+	  List_Read(listt,3,&zmax[0]);
+	  for(int i = 0; i < View->NbTP; i++){
+	    for(int j = 0; j< ((List_Nbr(listt)/View->NbTP)-3)/9; j++){
+	      List_Read(listt,i*it+3+j*9,&ztmp[0]);
+	      if(ztmp[0]<zmin[0]){zmin[0] = ztmp[0];}
+	      if(ztmp[0]>zmax[0]){zmax[0] = ztmp[0];}
+	    }
+	  }
+	  break;
+	case DRAW_POST_LMGC90_DEPY: 
+	  it = List_Nbr(listt)/View->NbTP;
+	  List_Read(listt,4,&zmin[0]);
+	  List_Read(listt,4,&zmax[0]);
+	  for(int i = 0; i < View->NbTP; i++){
+	    for(int j = 0; j< ((List_Nbr(listt)/View->NbTP)-3)/9; j++){
+	      List_Read(listt,i*it+4+j*9,&ztmp[0]);
+	      if(ztmp[0]<zmin[0]){zmin[0] = ztmp[0];}
+	      if(ztmp[0]>zmax[0]){zmax[0] = ztmp[0];}
+	    }
+	  }
+	break;
+	case DRAW_POST_LMGC90_DEPZ:
+	  it = List_Nbr(listt)/View->NbTP;
+	  List_Read(listt,5,&zmin[0]);
+	  List_Read(listt,5,&zmax[0]);
+	  for(int i = 0; i < View->NbTP; i++){
+	    for(int j = 0; j< ((List_Nbr(listt)/View->NbTP)-3)/9; j++){
+	      List_Read(listt,i*it+5+j*9,&ztmp[0]);
+	      if(ztmp[0]<zmin[0]){zmin[0] = ztmp[0];}
+	      if(ztmp[0]>zmax[0]){zmax[0] = ztmp[0];}
+	    }
+	  }
+	break;
+	case DRAW_POST_LMGC90_DEPAV:
+	  it = List_Nbr(listt)/View->NbTP;
+	  List_Read(listt,3,&ztmp[0]);
+	  List_Read(listt,4,&ztmp[1]);
+	  List_Read(listt,5,&ztmp[2]);
+	  zmin[0]=(ztmp[0]+ztmp[1]+ztmp[2])/3;
+	  List_Read(listt,3,&ztmp[0]);
+	  List_Read(listt,4,&ztmp[1]);
+	  List_Read(listt,5,&ztmp[2]);
+	  zmax[0]=(ztmp[0]+ztmp[1]+ztmp[2])/3;
+	  for(int i = 0; i < View->NbTP; i++){
+	    for(int j = 0; j< ((List_Nbr(listt)/View->NbTP)-3)/9; j++){
+	      List_Read(listt,i*it+3+j*9,&ztmp[0]);
+	      List_Read(listt,i*it+4+j*9,&ztmp[1]);
+	      List_Read(listt,i*it+5+j*9,&ztmp[2]);
+	      ztmp[0]=(ztmp[0]+ztmp[1]+ztmp[2])/3;
+	      if(ztmp[0]<zmin[0]){zmin[0] = ztmp[0];}
+	      if(ztmp[0]>zmax[0]){zmax[0] = ztmp[0];}
+	    }
+	  }
+	break;
+	case DRAW_POST_LMGC90_DEPNORM:
+	  it = List_Nbr(listt)/View->NbTP;
+	  List_Read(listt,3,&ztmp[0]);
+	  List_Read(listt,4,&ztmp[1]);
+	  List_Read(listt,5,&ztmp[2]);
+	  zmin[0]=sqrt(ztmp[0]*ztmp[0]+ztmp[1]*ztmp[1]+ztmp[2]*ztmp[2]);
+	  List_Read(listt,3,&ztmp[0]);
+	  List_Read(listt,4,&ztmp[1]);
+	  List_Read(listt,5,&ztmp[2]);
+	  zmax[0]=sqrt(ztmp[0]*ztmp[0]+ztmp[1]*ztmp[1]+ztmp[2]*ztmp[2]);
+	  for(int i = 0; i < View->NbTP; i++){
+	    for(int j = 0; j< ((List_Nbr(listt)/View->NbTP)-3)/9; j++){
+	      List_Read(listt,i*it+3+j*9,&ztmp[0]);
+	      List_Read(listt,i*it+4+j*9,&ztmp[1]);
+	      List_Read(listt,i*it+5+j*9,&ztmp[2]);
+	      ztmp[0]=sqrt(ztmp[0]*ztmp[0]+ztmp[1]*ztmp[1]+ztmp[2]*ztmp[2]);
+	      if(ztmp[0]<zmin[0]){zmin[0] = ztmp[0];}
+	      if(ztmp[0]>zmax[0]){zmax[0] = ztmp[0];}
+	    }
+	  }
+	  break;
+	}
+      }
+    // matrice de changement de base, pour la rotation
+//     a11 = cos(ROT[0])*cos(ROT[1]); a12 = -sin(ROT[0])*cos(ROT[1]); 	a13 = -sin(ROT[1]);
+//     a21 = sin(ROT[0])*cos(ROT[2])-cos(ROT[0])*sin(ROT[1])*sin(ROT[2]);
+//     a22 = cos(ROT[0])*cos(ROT[2])+sin(ROT[0])*sin(ROT[1])*sin(ROT[2]);
+//     a23 = -cos(ROT[1])*sin(ROT[2]);
+//     a31 = sin(ROT[0])*sin(ROT[2])+cos(ROT[0])*sin(ROT[1])*cos(ROT[2]);
+//     a32 = cos(ROT[0])*sin(ROT[2])-sin(ROT[0])*sin(ROT[1])*cos(ROT[2]);
+//     a33 = cos(ROT[1])*cos(ROT[2]);	
+    
+
+    switch (View->TensorType) {
+    case DRAW_POST_LMGC90: 
+      PaletteContinuous(View,zmin[0],zmax[0],1);
+      break;
+    case DRAW_POST_LMGC90_TYPE:
+      //	it = List_Nbr(listt)/View->NbTP;
+      //	List_Read(listt,V[6],&ztmp[0]);
+      //	PaletteContinuous(View,zmin[0],zmax[0],ztmp[0]); 
+      break;
+    case DRAW_POST_LMGC90_COORD:
+      // 	if(ts!=0){
+      // 	  PaletteContinuous(View,zmin[0],zmax[0],VAR[0]);} 
+      // 	else{
+      // 	  it = List_Nbr(listt)/View->NbTP;
+      // 	  List_Read(listt,V[6],&ztmp[0]);
+      // 	  PaletteContinuous(View,zmin[0],zmax[0],ztmp[0]); 
+      //	}
+      break;
+    case DRAW_POST_LMGC90_PRES:
+      PaletteContinuous(View,zmin[0],zmax[0],VAR[1]); 
+      break;
+    case DRAW_POST_LMGC90_SN:
+      PaletteContinuous(View,zmin[0],zmax[0],VAR[2]); 
+      break;
+    case DRAW_POST_LMGC90_DEPX:
+      PaletteContinuous(View,zmin[0],zmax[0],DEP[0]); 
+      break;
+    case DRAW_POST_LMGC90_DEPY:
+      PaletteContinuous(View,zmin[0],zmax[0],DEP[1]); 
+      break;
+    case DRAW_POST_LMGC90_DEPZ: 
+      PaletteContinuous(View,zmin[0],zmax[0],DEP[2]);
+      break;
+    case DRAW_POST_LMGC90_DEPAV:
+      PaletteContinuous(View,zmin[0],zmax[0],(DEP[0]+DEP[1]+DEP[2])/3);
+      break;
+    case DRAW_POST_LMGC90_DEPNORM:
+      PaletteContinuous(View,zmin[0],zmax[0],sqrt(DEP[0]*DEP[0]+DEP[1]*DEP[1]+DEP[2]*DEP[2]));
+      break;      
+    }
+
+    std::map<int,int> :: iterator iter = View->DisplayListsOfGrains->find ( (int)V[6] );
+    
+    glEnable(GL_LIGHTING);
+    if (iter == View->DisplayListsOfGrains->end() )
+    {
+      int listnum = glGenLists(1);
+      printf("new DL grain generated %d listnum %d \n",(int)V[6],listnum );
+      glNewList(listnum, GL_COMPILE);
+      (* View->DisplayListsOfGrains )[(int)V[6]] = listnum;
+      for(int i = 0; i < List_Nbr(list) ; i = i+9){
+	List_Read(list,i  ,&X[0]);	//X
+	List_Read(list,i+1,&Y[0]);	//Y
+	List_Read(list,i+2,&Z[0]);	//Z
+	List_Read(list,i+3,&X[1]);
+	List_Read(list,i+4,&Y[1]);
+	List_Read(list,i+5,&Z[1]);
+	List_Read(list,i+6,&X[2]);
+	List_Read(list,i+7,&Y[2]);
+	List_Read(list,i+8,&Z[2]);
+	double n[3];
+	normal3points(X[0], Y[0], Z[0], X[1], Y[1], Z[1], X[2], Y[2], Z[2], n);
+	glBegin(GL_TRIANGLES);
+	glNormal3dv(n);			
+	glVertex3d(X[0], Y[0], Z[0]);
+	glVertex3d(X[1], Y[1], Z[1]);
+	glVertex3d(X[2], Y[2], Z[2]);
+	glEnd();
+      } 
+      glEndList();
+    }
+    glPushMatrix(); 
+    //    glRotated (1,0,0, ROT[0] *180/M_PI);
+    //    glRotated (0,1,0, ROT[1] *180/M_PI);
+    glTranslated(CDG[0] + DEP[0], CDG[1] + DEP[1], CDG[2] + DEP [2]);
+    glRotated ( ROT[0] *180/M_PI, 0,0,1);
+    glRotated ( ROT[1] *180/M_PI, 1,0,0);
+    glRotated ( ROT[2] *180/M_PI, 0,1,0);
+    glCallList((* View->DisplayListsOfGrains )[(int)V[6]]);
+    glPopMatrix();    
+    glDisable(GL_LIGHTING);
+  }
 
   View->TimeStep = ts;
 }
