@@ -1,33 +1,23 @@
-/* $Id: gl2gif.cpp,v 1.21 2003/11/04 17:10:29 geuzaine Exp $ */
-/*
- * GL2GIF, an OpenGL to GIF Printing Library
- * Copyright (C) 1999-2003 Christophe Geuzaine <geuz@geuz.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of either:
- *
- * a) the GNU Library General Public License as published by the Free
- * Software Foundation, either version 2 of the License, or (at your
- * option) any later version; or
- *
- * b) the GL2PS License as published by Christophe Geuzaine, either
- * version 2 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See either
- * the GNU Library General Public License or the GL2PS License for
- * more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library in the file named "COPYING.LGPL";
- * if not, write to the Free Software Foundation, Inc., 675 Mass Ave,
- * Cambridge, MA 02139, USA.
- *
- * You should have received a copy of the GL2PS License with this
- * library in the file named "COPYING.GL2PS"; if not, I will be glad
- * to provide one.
- */
+// $Id: gl2gif.cpp,v 1.23 2006-12-04 03:27:31 geuzaine Exp $
+//
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+// USA.
+// 
+// Please report all bugs and problems to <gmsh@geuz.org>.
 
 /* 
  * Warning: This code is really a dirty hack. It SHOULD be cleaned
@@ -71,8 +61,6 @@
  *
  */
 
-#include "Gmsh.h"
-#include "GmshUI.h"
 #include "gl2gif.h"
 
 /* PPM colormap routines */
@@ -1172,7 +1160,7 @@ static void GIFEncode(FILE * fp,
 #define FS_SCALE   1024
 #define MAXCOL2    32767
 
-void create_gif(FILE * outfile, int width, int height,
+void create_gif(FILE * outfile, PixelBuffer *buffer,
                 int dither, int sort, int interlace,
                 int transparency, int bg_r, int bg_g, int bg_b)
 {
@@ -1181,7 +1169,6 @@ void create_gif(FILE * outfile, int width, int height,
   pixel transcolor;
   colorhist_vector chv, colormap;
   int BitsPerPixel, usehash;
-  unsigned char *RedBuffer, *GreenBuffer, *BlueBuffer;
   pixval maxval = MAXCOL2, newmaxval;
   colorhash_table cht;
   register pixel *pP;
@@ -1192,34 +1179,26 @@ void create_gif(FILE * outfile, int width, int height,
   register long sr = 0, sg = 0, sb = 0, err = 0;
   int fs_direction = 0;
 
-  /* This is stupid, but I couldn't figure out how to pack the data
-     directly from the OpenGL frame buffer into unsigned long
-     pixel[][] */
+  int width = buffer->GetWidth();
+  int height = buffer->GetHeight();
+  int numcomp = buffer->GetNumComp();
 
-  glPixelStorei(GL_PACK_ALIGNMENT, 1);
-  glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
-  RedBuffer = (unsigned char *)Malloc(height * width * sizeof(unsigned char));
-  GreenBuffer =
-    (unsigned char *)Malloc(height * width * sizeof(unsigned char));
-  BlueBuffer =
-    (unsigned char *)Malloc(height * width * sizeof(unsigned char));
-  glReadPixels(0, 0, width, height, GL_RED, GL_UNSIGNED_BYTE, RedBuffer);
-  glReadPixels(0, 0, width, height, GL_GREEN, GL_UNSIGNED_BYTE, GreenBuffer);
-  glReadPixels(0, 0, width, height, GL_BLUE, GL_UNSIGNED_BYTE, BlueBuffer);
+  if(numcomp != 3){
+    Msg(GERROR, "GIF only implemented for GL_RGB");
+    return;
+  }
 
   static_pixels = (pixel **) Malloc(height * sizeof(pixel *));
   for(i = 0; i < height; i++)
     static_pixels[i] = (pixel *) Malloc(3 * width * sizeof(pixel));
 
+  unsigned char *pixels = (unsigned char*)buffer->GetPixels();
   for(i = 0; i < height; i++)
     for(j = 0; j < width; j++)
       PPM_ASSIGN(static_pixels[height - 1 - i][j],
-                 RedBuffer[i * width + j],
-                 GreenBuffer[i * width + j], BlueBuffer[i * width + j]);
-
-  Free(RedBuffer);
-  Free(GreenBuffer);
-  Free(BlueBuffer);
+                 pixels[i * width * 3 + j * 3],
+                 pixels[i * width * 3 + j * 3 + 1],
+                 pixels[i * width * 3 + j * 3 + 2]);
 
   /* Try to compute color histogram */
 
