@@ -1,6 +1,6 @@
-// $Id: Numeric.cpp,v 1.25 2006/01/17 17:09:05 geuzaine Exp $
+// $Id: Numeric.cpp,v 1.31 2007-01-12 13:16:59 remacle Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -34,6 +34,8 @@
 
 #include <gsl/gsl_version.h>
 #include <gsl/gsl_errno.h>
+#include <gsl/gsl_vector.h>
+#include <gsl/gsl_linalg.h>
 
 void new_handler(const char *reason, const char *file, int line,
                  int gsl_errno)
@@ -58,13 +60,21 @@ int check_gsl()
   }
   // set new error handler
   gsl_set_error_handler(&new_handler);
+
+  // initilize robust geometric predicates
+  gmsh::exactinit() ;
   return 1;
 }
 
 #else
 
+#define NRANSI
+#include "nrutil.h"
+void dsvdcmp(double **a, int m, int n, double w[], double **v);
 int check_gsl()
 {
+  // initilize robust geometric predicates
+  gmsh::exactinit() ;
   return 1;
 }
 
@@ -247,6 +257,30 @@ int sys3x3_with_tol(double mat[3][3], double b[3], double res[3], double *det)
   return out;
 }
 
+double det2x2(double mat[2][2])
+{
+  return mat[0][0] *mat[1][1] -mat[1][0] *mat[0][1];
+}
+
+double inv2x2(double mat[2][2], double inv[2][2])
+{
+  const double det = det2x2 ( mat );
+  if(det){
+    double ud = 1. / det;
+    inv[0][0] =  ( mat[1][1] ) * ud ;
+    inv[1][0] = -( mat[1][0] ) * ud ;
+    inv[0][1] = -( mat[0][1] ) * ud ;
+    inv[1][1] =  ( mat[0][0] ) * ud ;
+  }
+  else{
+    Msg(GERROR, "Singular matrix");
+    for(int i = 0; i < 2; i++)
+      for(int j = 0; j < 2; j++)
+	inv[i][j] = 0.;
+  }
+  return det;
+}
+
 double inv3x3(double mat[3][3], double inv[3][3])
 {
   double det = det3x3(mat);
@@ -271,6 +305,79 @@ double inv3x3(double mat[3][3], double inv[3][3])
   return det;
 }
 
+void invert_singular_matrix3x3(double MM[3][3], double II[3][3])
+{
+  int i, j, k, n = 3;
+  double TT[3][3];
+
+  for(i = 1; i <= n; i++) {
+    for(j = 1; j <= n; j++) {
+      II[i - 1][j - 1] = 0.0;
+      TT[i - 1][j - 1] = 0.0;
+    }
+  }
+
+#if defined(HAVE_GSL)
+  gsl_matrix *M = gsl_matrix_alloc(3, 3);
+  gsl_matrix *V = gsl_matrix_alloc(3, 3);
+  gsl_vector *W = gsl_vector_alloc(3);
+  gsl_vector *TMPVEC = gsl_vector_alloc(3);
+  for(i = 1; i <= n; i++) {
+    for(j = 1; j <= n; j++) {
+      gsl_matrix_set(M, i - 1, j - 1, MM[i - 1][j - 1]);
+    }
+  }
+  gsl_linalg_SV_decomp(M, V, W, TMPVEC);
+  for(i = 1; i <= n; i++) {
+    for(j = 1; j <= n; j++) {
+      double ww = gsl_vector_get(W, i - 1);
+      if(fabs(ww) > 1.e-16) {   //singular value precision
+        TT[i - 1][j - 1] += gsl_matrix_get(M, j - 1, i - 1) / ww;
+      }
+    }
+  }
+  for(i = 1; i <= n; i++) {
+    for(j = 1; j <= n; j++) {
+      for(k = 1; k <= n; k++) {
+        II[i - 1][j - 1] +=
+          gsl_matrix_get(V, i - 1, k - 1) * TT[k - 1][j - 1];
+      }
+    }
+  }
+  gsl_matrix_free(M);
+  gsl_matrix_free(V);
+  gsl_vector_free(W);
+  gsl_vector_free(TMPVEC);
+#else
+  double **M = dmatrix(1, 3, 1, 3);
+  double **V = dmatrix(1, 3, 1, 3);
+  double *W = dvector(1, 3);
+  for(i = 1; i <= n; i++) {
+    for(j = 1; j <= n; j++) {
+      M[i][j] = MM[i - 1][j - 1];
+    }
+  }
+  dsvdcmp(M, n, n, W, V);
+  for(i = 1; i <= n; i++) {
+    for(j = 1; j <= n; j++) {
+      if(fabs(W[i]) > 1.e-16) { //singular value precision
+        TT[i - 1][j - 1] += M[j][i] / W[i];
+      }
+    }
+  }
+  for(i = 1; i <= n; i++) {
+    for(j = 1; j <= n; j++) {
+      for(k = 1; k <= n; k++) {
+        II[i - 1][j - 1] += V[i][k] * TT[k - 1][j - 1];
+      }
+    }
+  }
+  free_dmatrix(M, 1, n, 1, n);
+  free_dmatrix(V, 1, n, 1, n);
+  free_dvector(W, 1, n);
+#endif
+}
+
 double angle_02pi(double A3)
 {
   double DP = 2 * Pi;
@@ -283,6 +390,60 @@ double angle_02pi(double A3)
   return A3;
 }
 
+double angle_plan(double V[3], double P1[3], double P2[3], double n[3])
+{
+  double PA[3], PB[3], angplan;
+  double cosc, sinc, c[3];
+
+  PA[0] = P1[0] - V[0];
+  PA[1] = P1[1] - V[1];
+  PA[2] = P1[2] - V[2];
+
+  PB[0] = P2[0] - V[0];
+  PB[1] = P2[1] - V[1];
+  PB[2] = P2[2] - V[2];
+
+  norme(PA);
+  norme(PB);
+
+  prodve(PA, PB, c);
+
+  prosca(PA, PB, &cosc);
+  prosca(c, n, &sinc);
+  angplan = myatan2(sinc, cosc);
+
+  return angplan;
+}
+
+double triangle_area(double p0[3], double p1[3], double p2[3])
+{
+  double a[3], b[3], c[3];
+  
+  a[0] = p2[0] - p1[0];
+  a[1] = p2[1] - p1[1];
+  a[2] = p2[2] - p1[2];
+  
+  b[0] = p0[0] - p1[0];
+  b[1] = p0[1] - p1[1];
+  b[2] = p0[2] - p1[2];
+  
+  prodve(a, b, c);
+  return (0.5 * sqrt(c[0] * c[0] + c[1] * c[1] + c[2] * c[2]));
+}
+
+char float2char(float f)
+{
+  // f is supposed to be normalized in [-1, 1]
+  f = (f > 1.) ? 1. : (f < -1.) ? -1 : f;
+  // char is in [-128, 127]
+  return (char)(-128 + (f + 1.)/2. * 255);
+}
+
+float char2float(char c)
+{
+  return -1. + (float)(c + 128)/255. * 2.;
+}
+
 double InterpolateIso(double *X, double *Y, double *Z,
                       double *Val, double V, int I1, int I2,
                       double *XI, double *YI, double *ZI)
