@@ -1,7 +1,7 @@
 #ifndef _NUMERIC_H_
 #define _NUMERIC_H_
 
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -31,7 +31,6 @@
 #define MIN(a,b) (((a)<(b))?(a):(b))
 #define MAX(a,b) (((a)<(b))?(b):(a))
 #define SQR(a)   ((a)*(a))
-#define SIGN(a,b)((b) >= 0.0 ? fabs(a) : -fabs(a))
 
 #define IMIN MIN
 #define LMIN MIN
@@ -71,11 +70,18 @@ void normal3points(double x0, double y0, double z0,
 int sys2x2(double mat[2][2], double b[2], double res[2]);
 int sys3x3(double mat[3][3], double b[3], double res[3], double *det);
 int sys3x3_with_tol(double mat[3][3], double b[3], double res[3], double *det);
+double det2x2(double mat[2][2]);
 double det3x3(double mat[3][3]);
 double trace3x3(double mat[3][3]);
 double trace2 (double mat[3][3]);
 double inv3x3(double mat[3][3], double inv[3][3]);
+double inv2x2(double mat[2][2], double inv[2][2]);
+void invert_singular_matrix3x3(double MM[3][3], double II[3][3]);
 double angle_02pi(double A3);
+double angle_plan(double V[3], double P1[3], double P2[3], double n[3]);
+double triangle_area(double p0[3], double p1[3], double p2[3]);
+char float2char(float f);
+float char2float(char c);
 void eigenvalue(double mat[3][3], double re[3]);
 void FindCubicRoots(const double coeff[4], double re[3], double im[3]);
 void eigsort(double d[3]);
@@ -95,4 +101,13 @@ void mnbrak(double *ax, double *bx, double *cx, double *fa, double *fb,
 void newt(double x[], int n, int *check,
 	  void (*vecfunc)(int, double [], double []));
 
+/* Robust geometrical predicates */
+namespace gmsh{
+double exactinit();
+double incircle(double *pa, double *pb, double *pc, double *pd);
+double insphere(double *pa, double *pb, double *pc, double *pd, double *pe);
+double orient2d(double *pa, double *pb, double *pc);
+double orient3d(double *pa, double *pb, double *pc, double *pd);
+}
+
 #endif
