@@ -1,6 +1,6 @@
-// $Id: FunctionManager.cpp,v 1.22 2006/01/06 00:34:27 geuzaine Exp $
+// $Id: FunctionManager.cpp,v 1.25 2006-11-27 22:22:17 geuzaine Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -24,8 +24,6 @@
 #include <stack>
 #include "FunctionManager.h"
 
-using namespace std;
-
 struct ltstr
 {
   bool operator() (const char *s1, const char *s2)const
@@ -36,25 +34,23 @@ struct ltstr
 
 class File_Position
 {
-  public:int lineno;
+ public:
+  int lineno;
   fpos_t position;
   FILE *file;
   char filename[256];
 };
 
-// Pour utiliser un namespace global sur SGI, il faut compiler avec
-// -LANG:std, et ajouter "using namespace std;". Dans tous les cas, il
-// FAUT creer les librairies avec 'CC -ar', et pas avec 'ar'.
-
 class mystack
 {
-public:
-  stack < File_Position > s;
+ public:
+  std::stack<File_Position> s;
 };
 
 class mymap
 {
-  public: map < char *, File_Position, ltstr > m;
+ public: 
+  std::map<char*, File_Position, ltstr> m;
 };
 
 FunctionManager *FunctionManager::instance = 0;
