@@ -1,7 +1,7 @@
 #ifndef _PARSER_H_
 #define _PARSER_H_
 
-// Copyright (C) 1997-2005 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -21,18 +21,19 @@
 // Please report all bugs and problems to <gmsh@geuz.org>.
 
 #include "List.h"
+#include "Tree.h"
 
 typedef struct {
   char *Name;
   List_T *val;
 } Symbol;
 
-void InitSymbols (void);
+void InitSymbols();
 
 extern Tree_T *Symbol_T;
 
-int yyparse (void);
-int yylex ();
+int yyparse();
+int yylex();
 void force_yyflush();
 
 extern FILE *yyin;
@@ -41,5 +42,4 @@ extern char yyname[256];
 extern char *yytext;
 extern int yyerrorstate;
 
-
 #endif
