@@ -1,6 +1,6 @@
-// $Id: Curl.cpp,v 1.2 2006/01/06 00:34:32 geuzaine Exp $
+// $Id: Curl.cpp,v 1.4 2007-05-04 10:45:08 geuzaine Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@ void GMSH_CurlPlugin::getName(char *name) const
 void GMSH_CurlPlugin::getInfos(char *author, char *copyright,
 				    char *help_text) const
 {
-  strcpy(author, "C. Geuzaine (geuz@geuz.org)");
+  strcpy(author, "C. Geuzaine");
   strcpy(copyright, "DGR (www.multiphysics.com)");
   strcpy(help_text,
 	 "Plugin(Curl) computes the curl of the field\n"
