@@ -1,6 +1,6 @@
-// $Id: CutParametric.cpp,v 1.16 2006/01/06 00:34:32 geuzaine Exp $
+// $Id: CutParametric.cpp,v 1.19 2007-05-04 10:45:08 geuzaine Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -77,9 +77,9 @@ static double getU(int i)
 }
 
 int GMSH_CutParametricPlugin::recompute = 1;
-vector<double> GMSH_CutParametricPlugin::x;
-vector<double> GMSH_CutParametricPlugin::y;
-vector<double> GMSH_CutParametricPlugin::z;
+std::vector<double> GMSH_CutParametricPlugin::x;
+std::vector<double> GMSH_CutParametricPlugin::y;
+std::vector<double> GMSH_CutParametricPlugin::z;
 
 int GMSH_CutParametricPlugin::fillXYZ()
 {
@@ -221,7 +221,7 @@ void GMSH_CutParametricPlugin::getName(char *name) const
 void GMSH_CutParametricPlugin::getInfos(char *author, char *copyright,
                                    char *help_text) const
 {
-  strcpy(author, "C. Geuzaine (geuzaine@acm.caltech.edu)");
+  strcpy(author, "C. Geuzaine");
   strcpy(copyright, "DGR (www.multiphysics.com)");
   strcpy(help_text,
          "Plugin(CutParametric) cuts the view `iView' with\n"
