@@ -1,7 +1,7 @@
 #ifndef _CUT_PARAMETRIC_H_
 #define _CUT_PARAMETRIC_H_
 
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ private:
   static char *callbackStr(int num, int action, char *value, char **opt);
   static int fillXYZ();
   static int recompute;
-  static vector<double> x, y, z;
+  static std::vector<double> x, y, z;
 public:
   GMSH_CutParametricPlugin();
   void getName  (char *name) const;
