@@ -1,6 +1,6 @@
-// $Id: CutSphere.cpp,v 1.45 2006/01/06 00:34:32 geuzaine Exp $
+// $Id: CutSphere.cpp,v 1.47 2007-05-04 10:45:08 geuzaine Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -138,7 +138,7 @@ void GMSH_CutSpherePlugin::getName(char *name) const
 void GMSH_CutSpherePlugin::getInfos(char *author, char *copyright,
                                     char *help_text) const
 {
-  strcpy(author, "J.-F. Remacle (remacle@scorec.rpi.edu)");
+  strcpy(author, "J.-F. Remacle");
   strcpy(copyright, "DGR (www.multiphysics.com)");
   strcpy(help_text,
          "Plugin(CutSphere) cuts the view `iView' with the\n"
