@@ -1,6 +1,6 @@
-// $Id: Extract.cpp,v 1.19 2005/03/04 19:08:15 geuzaine Exp $
+// $Id: Extract.cpp,v 1.23 2007-05-04 10:45:08 geuzaine Exp $
 //
-// Copyright (C) 1997-2005 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -38,7 +38,11 @@ StringXNumber ExtractOptions_Number[] = {
 };
 
 StringXString ExtractOptions_String[] = {
+#if defined(HAVE_MATH_EVAL)
+  {GMSH_FULLRC, "Expression0", NULL, "Sqrt(v0^2+v1^2+v2^2)"},
+#else
   {GMSH_FULLRC, "Expression0", NULL, "v0"},
+#endif
   {GMSH_FULLRC, "Expression1", NULL, ""},
   {GMSH_FULLRC, "Expression2", NULL, ""},
   {GMSH_FULLRC, "Expression3", NULL, ""},
@@ -69,7 +73,7 @@ void GMSH_ExtractPlugin::getName(char *name) const
 
 void GMSH_ExtractPlugin::getInfos(char *author, char *copyright, char *help_text) const
 {
-  strcpy(author, "C. Geuzaine (geuz@geuz.org)");
+  strcpy(author, "C. Geuzaine");
   strcpy(copyright, "DGR (www.multiphysics.com)");
   strcpy(help_text,
          "Plugin(Extract) extracts a combination of\n"
