@@ -1,6 +1,6 @@
-// $Id: ExtractEdges.cpp,v 1.2.2.1 2006/03/15 19:13:55 geuzaine Exp $
+// $Id: ExtractEdges.cpp,v 1.4 2006-11-27 22:22:32 geuzaine Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -99,7 +99,10 @@ Post_View *GMSH_ExtractEdgesPlugin::execute(Post_View * v)
 
   BDS_Mesh bds;
   bds.import_view(v1, CTX.lc * 1.e-12);
-  bds.classify(angle * M_PI / 180.);
+  //  bds.classify(angle * M_PI / 180.);
+
+  Msg(GERROR, "BDS->classify(angle, edge_prolongation) must be reinterfaced");
+
   std::list<BDS_Edge*>::iterator it  = bds.edges.begin();
   std::list<BDS_Edge*>::iterator ite = bds.edges.end();
   while (it != ite){
