@@ -1,6 +1,6 @@
-// $Id: Gradient.cpp,v 1.5 2005/01/12 19:10:41 geuzaine Exp $
+// $Id: Gradient.cpp,v 1.8 2007-05-04 10:45:09 geuzaine Exp $
 //
-// Copyright (C) 1997-2005 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@ void GMSH_GradientPlugin::getName(char *name) const
 void GMSH_GradientPlugin::getInfos(char *author, char *copyright,
 				    char *help_text) const
 {
-  strcpy(author, "C. Geuzaine (geuz@geuz.org)");
+  strcpy(author, "C. Geuzaine");
   strcpy(copyright, "DGR (www.multiphysics.com)");
   strcpy(help_text,
 	 "Plugin(Gradient) computes the gradient of the\n"
