@@ -1,6 +1,6 @@
-// $Id: ModulusPhase.cpp,v 1.3 2006/02/15 04:47:35 geuzaine Exp $
+// $Id: ModulusPhase.cpp,v 1.5 2007-05-04 10:45:09 geuzaine Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -56,7 +56,7 @@ void GMSH_ModulusPhasePlugin::getName(char *name) const
 void GMSH_ModulusPhasePlugin::getInfos(char *author, char *copyright,
                                         char *help_text) const
 {
-  strcpy(author, "C. Geuzaine (geuz@geuz.org)");
+  strcpy(author, "C. Geuzaine");
   strcpy(copyright, "DGR (www.multiphysics.com)");
   strcpy(help_text,
          "Plugin(ModulusPhase) interprets the time steps\n"
