@@ -1,6 +1,6 @@
-// $Id: Probe.cpp,v 1.12 2006/01/06 00:34:33 geuzaine Exp $
+// $Id: Probe.cpp,v 1.14 2007-05-04 10:45:09 geuzaine Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -129,7 +129,7 @@ void GMSH_ProbePlugin::getName(char *name) const
 void GMSH_ProbePlugin::getInfos(char *author, char *copyright,
                                    char *help_text) const
 {
-  strcpy(author, "C. Geuzaine (geuzaine@acm.caltech.edu)");
+  strcpy(author, "C. Geuzaine");
   strcpy(copyright, "DGR (www.multiphysics.com)");
   strcpy(help_text,
          "Plugin(Probe) gets the value of the view `iView' at\n"
