@@ -1,6 +1,6 @@
-// $Id: Smooth.cpp,v 1.22 2006/01/06 00:34:33 geuzaine Exp $
+// $Id: Smooth.cpp,v 1.24 2007-05-04 10:45:09 geuzaine Exp $
 //
-// Copyright (C) 1997-2006 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ void GMSH_SmoothPlugin::getName(char *name) const
 void GMSH_SmoothPlugin::getInfos(char *author, char *copyright,
                                  char *help_text) const
 {
-  strcpy(author, "C. Geuzaine (geuz@geuz.org)");
+  strcpy(author, "C. Geuzaine");
   strcpy(copyright, "DGR (www.multiphysics.com)");
   strcpy(help_text,
          "Plugin(Smooth) averages the values at the nodes\n"
