@@ -1,6 +1,6 @@
-// $Id: SphericalRaise.cpp,v 1.22 2005/01/01 19:35:39 geuzaine Exp $
+// $Id: SphericalRaise.cpp,v 1.26 2007-05-05 11:36:32 geuzaine Exp $
 //
-// Copyright (C) 1997-2005 C. Geuzaine, J.-F. Remacle
+// Copyright (C) 1997-2007 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@ StringXNumber SphericalRaiseOptions_Number[] = {
   {GMSH_FULLRC, "Yc", NULL, 0.},
   {GMSH_FULLRC, "Zc", NULL, 0.},
   {GMSH_FULLRC, "Raise", NULL, 1.},
+  {GMSH_FULLRC, "Offset", NULL, 0.},
   {GMSH_FULLRC, "TimeStep", NULL, 0.},
   {GMSH_FULLRC, "iView", NULL, -1.}
 };
@@ -59,19 +60,22 @@ void GMSH_SphericalRaisePlugin::getName(char *name) const
 void GMSH_SphericalRaisePlugin::getInfos(char *author, char *copyright,
                                          char *help_text) const
 {
-  strcpy(author, "C. Geuzaine (geuz@geuz.org)");
+  strcpy(author, "C. Geuzaine");
   strcpy(copyright, "DGR (www.multiphysics.com)");
   strcpy(help_text,
          "Plugin(SphericalRaise) transforms the\n"
-         "coordinates of the elements in the view `iView'\n"
-         "using the values associated with the\n"
+         "coordinates of the elements in the view\n"
+         "`iView' using the values associated with the\n"
          "`TimeStep'-th time step. Instead of elevating\n"
          "the nodes along the X, Y and Z axes as in\n"
 	 "View[`iView'].RaiseX, View[`iView'].RaiseY\n"
 	 "and View[`iView'].RaiseZ, the raise is applied\n"
-	 " along the radius of a sphere centered at (`Xc',\n"
-	 "`Yc', `Zc'). If `iView' < 0, the plugin is run\n"
-	 "on the current view.\n"
+	 " along the radius of a sphere centered at\n"
+	 "(`Xc', `Yc', `Zc'). To produce a standard\n"
+	 "radiation pattern, set `Offset' to minus the\n"
+	 "radius of the sphere the original data lives on.\n"
+	 "If `iView' < 0, the plugin is run on the current\n"
+	 "view.\n"
 	 "\n"
 	 "Plugin(SphericalRaise) is executed in-place.\n");
 }
@@ -93,7 +97,7 @@ void GMSH_SphericalRaisePlugin::catchErrorMessage(char *errorMessage) const
 
 static void sphericalRaiseList(Post_View * v, List_T * list, int nbElm,
                                int nbNod, int timeStep, double center[3], 
-			       double raise)
+			       double raise, double offset)
 {
   double *x, *y, *z, *val, d[3], coef;
   int nb, i, j;
@@ -101,7 +105,7 @@ static void sphericalRaiseList(Post_View * v, List_T * list, int nbElm,
   if(!nbElm)
     return;
 
-  if(timeStep > v->NbTimeStep - 1){
+  if(timeStep < 0 || timeStep > v->NbTimeStep - 1){
     Msg(GERROR, "Invalid TimeStep (%d) in View[%d]", timeStep, v->Index);
     return;
   }
@@ -113,7 +117,7 @@ static void sphericalRaiseList(Post_View * v, List_T * list, int nbElm,
   //      compute d=(x-Xc,y-Yc,z-Zc)
   //      norm d
   //      get nodal value val at xyz
-  //      compute (x,y,z)_new = (x,y,z)_old + raise*val*(dx,dy,dz)
+  //      compute (x,y,z)_new = (x,y,z)_old + (offset+raise*val)*(dx,dy,dz)
 
   nb = List_Nbr(list) / nbElm;
   for(i = 0; i < List_Nbr(list); i += nb) {
@@ -126,10 +130,7 @@ static void sphericalRaiseList(Post_View * v, List_T * list, int nbElm,
       d[1] = y[j] - center[1];
       d[2] = z[j] - center[2];
       norme(d);
-      if(timeStep < 0)
-	coef = raise;
-      else
-	coef = raise * val[nbNod * timeStep + j];
+      coef = offset + raise * val[nbNod * timeStep + j];
       x[j] += coef * d[0];
       y[j] += coef * d[1];
       z[j] += coef * d[2];
@@ -144,32 +145,33 @@ static void sphericalRaiseList(Post_View * v, List_T * list, int nbElm,
 }
 
 static void sphericalRaise(Post_View * v, int timeStep, double center[3], 
-			   double raise)
+			   double raise, double offset)
 {
   for(int i = 0; i < 3; i++) {
     v->BBox[2 * i] = VAL_INF;
     v->BBox[2 * i + 1] = -VAL_INF;
   }
-  sphericalRaiseList(v, v->SP, v->NbSP, 1, timeStep, center, raise);
-  sphericalRaiseList(v, v->SL, v->NbSL, 2, timeStep, center, raise);
-  sphericalRaiseList(v, v->ST, v->NbST, 3, timeStep, center, raise);
-  sphericalRaiseList(v, v->SQ, v->NbSQ, 4, timeStep, center, raise);
-  sphericalRaiseList(v, v->SS, v->NbSS, 4, timeStep, center, raise);
-  sphericalRaiseList(v, v->SH, v->NbSH, 8, timeStep, center, raise);
-  sphericalRaiseList(v, v->SI, v->NbSI, 6, timeStep, center, raise);
-  sphericalRaiseList(v, v->SY, v->NbSY, 5, timeStep, center, raise);
+  sphericalRaiseList(v, v->SP, v->NbSP, 1, timeStep, center, raise, offset);
+  sphericalRaiseList(v, v->SL, v->NbSL, 2, timeStep, center, raise, offset);
+  sphericalRaiseList(v, v->ST, v->NbST, 3, timeStep, center, raise, offset);
+  sphericalRaiseList(v, v->SQ, v->NbSQ, 4, timeStep, center, raise, offset);
+  sphericalRaiseList(v, v->SS, v->NbSS, 4, timeStep, center, raise, offset);
+  sphericalRaiseList(v, v->SH, v->NbSH, 8, timeStep, center, raise, offset);
+  sphericalRaiseList(v, v->SI, v->NbSI, 6, timeStep, center, raise, offset);
+  sphericalRaiseList(v, v->SY, v->NbSY, 5, timeStep, center, raise, offset);
 }
 
 Post_View *GMSH_SphericalRaisePlugin::execute(Post_View * v)
 {
-  double center[3], raise;
+  double center[3];
 
   center[0] = SphericalRaiseOptions_Number[0].def;
   center[1] = SphericalRaiseOptions_Number[1].def;
   center[2] = SphericalRaiseOptions_Number[2].def;
-  raise = SphericalRaiseOptions_Number[3].def;
-  int timeStep = (int)SphericalRaiseOptions_Number[4].def;
-  int iView = (int)SphericalRaiseOptions_Number[5].def;
+  double raise = SphericalRaiseOptions_Number[3].def;
+  double offset = SphericalRaiseOptions_Number[4].def;
+  int timeStep = (int)SphericalRaiseOptions_Number[5].def;
+  int iView = (int)SphericalRaiseOptions_Number[6].def;
 
   if(iView < 0)
     iView = v ? v->Index : 0;
@@ -181,7 +183,7 @@ Post_View *GMSH_SphericalRaisePlugin::execute(Post_View * v)
 
   Post_View *v1 = *(Post_View **)List_Pointer(CTX.post.list, iView);
 
-  sphericalRaise(v1, timeStep, center, raise);
+  sphericalRaise(v1, timeStep, center, raise, offset);
   return v1;
 }
 
